@@ -110,7 +110,7 @@ virt_builder_pxzcat (value inputfilev, value outputfilev)
 
   pid = fork ();
   if (pid == -1) {
-    int err = errno;
+    const int err = errno;
     close (fd);
     unix_error (err, (char *) "fork", Nothing);
   }
@@ -166,6 +166,9 @@ pxzcat (value filenamev, value outputfilev, unsigned nr_threads)
   if (fd == -1)
     unix_error (errno, (char *) "open", filenamev);
 
+  guestfs_int_fadvise_noreuse (fd);
+  guestfs_int_fadvise_random (fd);
+
   /* Check file magic. */
   if (!check_header_magic (fd)) {
     close (fd);
@@ -185,40 +188,37 @@ pxzcat (value filenamev, value outputfilev, unsigned nr_threads)
    */
   ofd = open (String_val (outputfilev), O_WRONLY|O_CREAT|O_NOCTTY, 0644);
   if (ofd == -1) {
-    int err = errno;
+    const int err = errno;
     close (fd);
     unix_error (err, (char *) "open", outputfilev);
   }
 
+  guestfs_int_fadvise_random (ofd);
+
   if (ftruncate (ofd, 1) == -1) {
-    int err = errno;
+    const int err = errno;
     close (fd);
     unix_error (err, (char *) "ftruncate", outputfilev);
   }
 
   if (lseek (ofd, 0, SEEK_SET) == -1) {
-    int err = errno;
+    const int err = errno;
     close (fd);
     unix_error (err, (char *) "lseek", outputfilev);
   }
 
   if (write (ofd, "\0", 1) == -1) {
-    int err = errno;
+    const int err = errno;
     close (fd);
     unix_error (err, (char *) "write", outputfilev);
   }
 
   if (ftruncate (ofd, size) == -1) {
-    int err = errno;
+    const int err = errno;
     close (fd);
     unix_error (err, (char *) "ftruncate", outputfilev);
   }
 
-#if defined HAVE_POSIX_FADVISE
-  /* Tell the kernel we won't read the output file. */
-  ignore_value (posix_fadvise (fd, 0, 0, POSIX_FADV_RANDOM|POSIX_FADV_DONTNEED));
-#endif
-
   /* Iterate over blocks. */
   iter_blocks (idx, nr_threads, filenamev, fd, outputfilev, ofd);
 
@@ -226,6 +226,9 @@ pxzcat (value filenamev, value outputfilev, unsigned nr_threads)
 
   if (close (fd) == -1)
     unix_error (errno, (char *) "close", filenamev);
+
+  if (close (ofd) == -1)
+    unix_error (errno, (char *) "close", outputfilev);
 }
 
 static int
