@@ -24,8 +24,8 @@ fn=test-filename-for-index-validate
 rm -f $fn
 touch $fn
 
-$VG ../virt-index-validate $srcdir/index
-$VG ../virt-index-validate $srcdir/index.asc
-$VG ../virt-index-validate $fn
+$VG virt-index-validate $srcdir/index
+$VG virt-index-validate $srcdir/index.asc
+$VG virt-index-validate $fn
 
 rm $fn
