@@ -131,7 +131,7 @@ main (int argc, char *argv[])
 
   enum { HELP_OPTION = CHAR_MAX + 1 };
 
-  static const char *options = "a:c:d:hlm:RvVx";
+  static const char options[] = "a:c:d:hlm:RvVx";
   static const struct option long_options[] = {
     { "add", 1, 0, 'a' },
     { "checksum", 2, 0, 0 },
@@ -352,8 +352,11 @@ main (int argc, char *argv[])
     usage (EXIT_FAILURE);
 
   /* User must have specified some drives. */
-  if (drvs == NULL)
+  if (drvs == NULL) {
+    fprintf (stderr, _("%s: error: you must specify at least one -a or -d option.\n"),
+             guestfs_int_program_name);
     usage (EXIT_FAILURE);
+  }
 
   /* Add drives, inspect and mount. */
   add_drives (drvs, 'a');
@@ -559,7 +562,7 @@ static int field;
 static void
 next_field (void)
 {
-  int c = csv ? ',' : ' ';
+  const int c = csv ? ',' : ' ';
 
   field++;
   if (field == 1) return;
@@ -670,7 +673,8 @@ static void
 output_int64_size (int64_t size)
 {
   char buf[LONGEST_HUMAN_READABLE];
-  int hopts = human_round_to_nearest|human_autoscale|human_base_1024|human_SI;
+  const int hopts =
+    human_round_to_nearest|human_autoscale|human_base_1024|human_SI;
   int r;
 
   next_field ();
