@@ -38,7 +38,7 @@ let main () =
     | "auto" -> attach_format := None
     | s -> attach_format := Some s
   in
-  let attach_disk s = attach := (!attach_format, s) :: !attach in
+  let attach_disk s = push_front (!attach_format, s) attach in
   let domain = ref None in
   let dryrun = ref false in
   let files = ref [] in
@@ -62,7 +62,7 @@ let main () =
         error (f_"error parsing URI '%s'. Look for error messages printed above.")
           arg in
     let format = match !format with "auto" -> None | fmt -> Some fmt in
-    files := (uri, format) :: !files;
+    push_front (uri, format) files;
     format_consumed := true
   and set_domain dom =
     if !domain <> None then
@@ -135,9 +135,9 @@ read the man page virt-customize(1).
                   ~readonly ?discard
                   ?libvirturi ~allowuuid ~readonlydisk
                   dom)
-    | _, Some _ ->
+    | _::_, Some _ ->
       error (f_"you cannot give -a and -d options together. Read virt-customize(1) man page for further information.")
-    | files, None ->
+    | (_::_) as files, None ->
       fun g readonly ->
         List.iter (
           fun (uri, format) ->
