@@ -50,7 +50,7 @@ let run (g : Guestfs.guestfs) root (ops : ops) =
       warning (f_"log file %s: %s (ignored)") logfile (Printexc.to_string exn) in
 
   (* Useful wrapper for scripts. *)
-  let do_run ~display cmd =
+  let do_run ~display ?(warn_failed_no_network = false) cmd =
     if not guest_arch_compatible then
       error (f_"host cpu (%s) and guest arch (%s) are not compatible, so you cannot use command line options that involve running commands in the guest.  Use --firstboot scripts instead.")
             Guestfs_config.host_cpu guest_arch;
@@ -85,16 +85,21 @@ exec >>%s 2>&1
 %s
 " (quote logfile) env_vars cmd in
 
-    if verbose () then printf "running command:\n%s\n%!" cmd;
+    debug "running command:\n%s" cmd;
     try ignore (g#sh cmd)
     with
       Guestfs.Error msg ->
         debug_logfile ();
+        if warn_failed_no_network && not (g#get_network ()) then (
+          prerr_newline ();
+          warning (f_"the command may have failed because the network is disabled.  Try either removing '--no-network' or adding '--network' on the command line.");
+          prerr_newline ()
+        );
         error (f_"%s: command exited with an error") display
   in
 
   (* http://distrowatch.com/dwres.php?resource=package-management *)
-  let guest_install_command packages =
+  let rec guest_install_command packages =
     let quoted_args = String.concat " " (List.map quote packages) in
     match g#inspect_get_package_management root with
     | "apt" ->
@@ -110,7 +115,7 @@ exec >>%s 2>&1
     | "pisi" ->
       sprintf "pisi it %s" quoted_args
     | "pacman" ->
-      sprintf "pacman -S %s" quoted_args
+      sprintf "pacman -S --noconfirm %s" quoted_args
     | "urpmi" ->
       sprintf "urpmi %s" quoted_args
     | "yum" ->
@@ -118,9 +123,9 @@ exec >>%s 2>&1
     | "zypper" ->
       sprintf "zypper -n in -l %s" quoted_args
     | "unknown" ->
-      error (f_"--install is not supported for this guest operating system")
+      error_unknown_package_manager (s_"--install")
     | pm ->
-      error (f_"sorry, don't know how to use --install with the '%s' package manager") pm
+      error_unimplemented_package_manager (s_"--install") pm
 
   and guest_update_command () =
     match g#inspect_get_package_management root with
@@ -145,9 +150,16 @@ exec >>%s 2>&1
     | "zypper" ->
       sprintf "zypper -n update -l"
     | "unknown" ->
-      error (f_"--update is not supported for this guest operating system")
+      error_unknown_package_manager (s_"--update")
     | pm ->
-      error (f_"sorry, don't know how to use --update with the '%s' package manager") pm
+      error_unimplemented_package_manager (s_"--update") pm
+
+  (* Windows has package_management == "unknown". *)
+  and error_unknown_package_manager flag =
+    error (f_"cannot use '%s' because no package manager has been detected for this guest OS.\n\nIf this guest OS is a common one with ordinary package management then this may have been caused by a failure of libguestfs inspection.\n\nFor OSes such as Windows that lack package management, this is not possible.  Try using one of the '--firstboot*' flags instead (described in the manual).") flag
+
+  and error_unimplemented_package_manager flag pm =
+      error (f_"sorry, '%s' with the '%s' package manager has not been implemented yet.\n\nYou can work around this by using one of the '--run*' or '--firstboot*' options instead (described in the manual).") flag pm
   in
 
   (* Set the random seed. *)
@@ -230,7 +242,7 @@ exec >>%s 2>&1
     | `InstallPackages pkgs ->
       message (f_"Installing packages: %s") (String.concat " " pkgs);
       let cmd = guest_install_command pkgs in
-      do_run ~display:cmd cmd
+      do_run ~display:cmd ~warn_failed_no_network:true cmd
 
     | `Link (target, links) ->
       List.iter (
@@ -267,11 +279,11 @@ exec >>%s 2>&1
       | Subscription_manager.PoolAuto ->
         message (f_"Attaching to compatible subscriptions");
         let cmd = "subscription-manager attach --auto" in
-        do_run ~display:cmd cmd
+        do_run ~display:cmd ~warn_failed_no_network:true cmd
       | Subscription_manager.PoolId id ->
         message (f_"Attaching to the pool %s") id;
         let cmd = sprintf "subscription-manager attach --pool=%s" (quote id) in
-        do_run ~display:cmd cmd
+        do_run ~display:cmd ~warn_failed_no_network:true cmd
       )
 
     | `SMRegister ->
@@ -284,17 +296,18 @@ exec >>%s 2>&1
       let cmd = sprintf "subscription-manager register --username=%s --password=%s"
                   (quote creds.Subscription_manager.sm_username)
                   (quote creds.Subscription_manager.sm_password) in
-      do_run ~display:"subscription-manager register" cmd
+      do_run ~display:"subscription-manager register"
+             ~warn_failed_no_network:true cmd
 
     | `SMRemove ->
       message (f_"Removing all the subscriptions");
       let cmd = "subscription-manager remove --all" in
-      do_run ~display:cmd cmd
+      do_run ~display:cmd ~warn_failed_no_network:true cmd
 
     | `SMUnregister ->
       message (f_"Unregistering with subscription-manager");
       let cmd = "subscription-manager unregister" in
-      do_run ~display:cmd cmd
+      do_run ~display:cmd ~warn_failed_no_network:true cmd
 
     | `SSHInject (user, selector) ->
       (match g#inspect_get_type root with
@@ -322,9 +335,9 @@ exec >>%s 2>&1
       g#touch path
 
     | `Update ->
-      message (f_"Updating core packages");
+      message (f_"Updating packages");
       let cmd = guest_update_command () in
-      do_run ~display:cmd cmd
+      do_run ~display:cmd ~warn_failed_no_network:true cmd
 
     | `Upload (path, dest) ->
       message (f_"Uploading: %s to %s") path dest;
@@ -408,6 +421,6 @@ exec >>%s 2>&1
   (try ignore (g#debug "sh" [| "fuser"; "-k"; "/sysroot" |])
    with exn ->
      if verbose () then
-       printf (f_"%s: %s (ignored)\n") prog (Printexc.to_string exn)
+       warning (f_"%s (ignored)") (Printexc.to_string exn)
   );
   g#ping_daemon () (* tiny delay after kill *)
