@@ -40,7 +40,7 @@ do_internal_feature_available (const char *group)
 
   for (i = 0; optgroups[i].group != NULL; ++i) {
     if (STREQ (group, optgroups[i].group)) {
-      int av = optgroups[i].available ();
+      const int av = optgroups[i].available ();
       return av ? 0 : 1;
     }
   }
@@ -53,7 +53,7 @@ char **
 do_available_all_groups (void)
 {
   size_t i;
-  DECLARE_STRINGSBUF (groups);
+  CLEANUP_FREE_STRINGSBUF DECLARE_STRINGSBUF (groups);
 
   for (i = 0; optgroups[i].group != NULL; ++i) {
     if (add_string (&groups, optgroups[i].group) == -1)
@@ -63,7 +63,7 @@ do_available_all_groups (void)
   if (end_stringsbuf (&groups) == -1)
     return NULL;
 
-  return groups.argv;           /* caller frees */
+  return take_stringsbuf (&groups);           /* caller frees */
 }
 
 /* Search for filesystem in /proc/filesystems, ignoring "nodev". */
@@ -120,7 +120,8 @@ filesystem_available (const char *filesystem)
 int
 do_filesystem_available (const char *filesystem)
 {
-  size_t i, len = strlen (filesystem);
+  size_t i;
+  const size_t len = strlen (filesystem);
   int r;
 
   for (i = 0; i < len; ++i) {
