@@ -1,5 +1,5 @@
 /* libguestfs - the guestfsd daemon
- * Copyright (C) 2009-2014 Red Hat Inc.
+ * Copyright (C) 2009-2016 Red Hat Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -83,6 +83,9 @@ static void deliberately_cause_a_segfault (void);
 static struct cmd cmds[] = {
   { "help", debug_help },
   { "binaries", debug_binaries },
+  { "bmap", debug_bmap },
+  { "bmap_device", debug_bmap_device },
+  { "bmap_file", debug_bmap_file },
   { "core_pattern", debug_core_pattern },
   { "device_speed", debug_device_speed },
   { "env", debug_env },
@@ -433,7 +436,7 @@ debug_ldd (const char *subcmd, size_t argc, char *const *const argv)
 static char *
 debug_ls (const char *subcmd, size_t argc, char *const *const argv)
 {
-  size_t len = count_strings (argv);
+  const size_t len = count_strings (argv);
   const char *cargv[len+3];
   size_t i;
   int r;
@@ -460,7 +463,7 @@ debug_ls (const char *subcmd, size_t argc, char *const *const argv)
 static char *
 debug_ll (const char *subcmd, size_t argc, char *const *const argv)
 {
-  size_t len = count_strings (argv);
+  const size_t len = count_strings (argv);
   const char *cargv[len+3];
   size_t i;
   int r;
@@ -544,7 +547,7 @@ debug_progress (const char *subcmd, size_t argc, char *const *const argv)
     uint64_t tsecs = secs * 10; /* 1/10ths of seconds */
     uint64_t i;
 
-    for (i = 1; i <= tsecs; ++i) {
+    for (i = 1; i < tsecs+1; ++i) {
       usleep (100000);
       notify_progress (i, tsecs);
     }
@@ -585,7 +588,7 @@ debug_core_pattern (const char *subcmd, size_t argc, char *const *const argv)
   }
 
   const char *pattern = argv[0];
-  const size_t pattern_len = strlen(pattern);
+  const size_t pattern_len = strlen (pattern);
 
 #define CORE_PATTERN "/proc/sys/kernel/core_pattern"
   int fd = open (CORE_PATTERN, O_WRONLY|O_CLOEXEC);
@@ -660,7 +663,7 @@ debug_spew (const char *subcmd, size_t argc, char *const *const argv)
 static int
 write_cb (void *fd_ptr, const void *buf, size_t len)
 {
-  int fd = *(int *)fd_ptr;
+  const int fd = *(int *)fd_ptr;
   return xwrite (fd, buf, len);
 }
 
@@ -885,7 +888,7 @@ do_debug_upload (const char *filename, int mode)
   int fd = open (filename, O_WRONLY|O_CREAT|O_TRUNC|O_NOCTTY|O_CLOEXEC, mode);
 
   if (fd == -1) {
-    int err = errno;
+    const int err = errno;
     cancel_receive ();
     errno = err;
     reply_with_perror ("%s", filename);
@@ -894,7 +897,7 @@ do_debug_upload (const char *filename, int mode)
 
   int r = receive_file (write_cb, &fd);
   if (r == -1) {		/* write error */
-    int err = errno;
+    const int err = errno;
     cancel_receive ();
     errno = err;
     reply_with_error ("write error: %s", filename);
@@ -957,7 +960,7 @@ do_internal_rhbz914931 (int count)
 
   r = receive_file (crash_cb, &count);
   if (r == -1) {		/* write error */
-    int err = errno;
+    const int err = errno;
     cancel_receive ();
     errno = err;
     reply_with_error ("write error");
