@@ -80,7 +80,7 @@ do_fill (int c, int len, const char *path)
 int
 do_fill_pattern (const char *pattern, int len, const char *path)
 {
-  size_t patlen = strlen (pattern);
+  const size_t patlen = strlen (pattern);
 
   if (patlen < 1) {
     reply_with_error ("pattern string must be non-empty");
@@ -91,7 +91,7 @@ do_fill_pattern (const char *pattern, int len, const char *path)
     reply_with_error ("%d: length is < 0", len);
     return -1;
   }
-  size_t len_sz = (size_t) len;
+  const size_t len_sz = (size_t) len;
 
   int fd;
   CHROOT_IN;
@@ -106,7 +106,7 @@ do_fill_pattern (const char *pattern, int len, const char *path)
   /* XXX This implementation won't be very efficient for large files. */
   size_t n = 0;
   while (n < len_sz) {
-    size_t wrlen = len_sz - n < patlen ? len_sz - n : patlen;
+    const size_t wrlen = len_sz - n < patlen ? len_sz - n : patlen;
     if (xwrite (fd, pattern, wrlen) == -1) {
       reply_with_perror ("write: %s", path);
       close (fd);
