@@ -48,7 +48,7 @@ static char **
 convert_lvm_output (char *out, const char *prefix)
 {
   char *p, *pend;
-  DECLARE_STRINGSBUF (ret);
+  CLEANUP_FREE_STRINGSBUF DECLARE_STRINGSBUF (ret);
   size_t len;
   char buf[256];
   char *str;
@@ -100,7 +100,7 @@ convert_lvm_output (char *out, const char *prefix)
   if (end_stringsbuf (&ret) == -1)
     return NULL;
 
-  return ret.argv;
+  return take_stringsbuf (&ret);
 }
 
 /* Filter a colon-separated output of
@@ -113,7 +113,7 @@ static char **
 filter_convert_old_lvs_output (char *out)
 {
   char *p, *pend;
-  DECLARE_STRINGSBUF (ret);
+  CLEANUP_FREE_STRINGSBUF DECLARE_STRINGSBUF (ret);
 
   p = out;
   while (p) {
@@ -183,7 +183,7 @@ filter_convert_old_lvs_output (char *out)
   if (end_stringsbuf (&ret) == -1)
     return NULL;
 
-  return ret.argv;
+  return take_stringsbuf (&ret);
 }
 
 char **
@@ -255,7 +255,7 @@ do_lvs (void)
   char *out;
   CLEANUP_FREE char *err = NULL;
   int r;
-  int has_S = test_lvs_has_S_opt ();
+  const int has_S = test_lvs_has_S_opt ();
 
   if (has_S < 0)
     return NULL;
@@ -889,7 +889,7 @@ do_lvm_canonical_lv_name (const char *device)
 char **
 do_list_dm_devices (void)
 {
-  DECLARE_STRINGSBUF (ret);
+  CLEANUP_FREE_STRINGSBUF DECLARE_STRINGSBUF (ret);
   struct dirent *d;
   DIR *dir;
   int r;
@@ -921,7 +921,6 @@ do_list_dm_devices (void)
     /* Ignore dm devices which are LVs. */
     r = lv_canonical (devname, NULL);
     if (r == -1) {
-      free_stringslen (ret.argv, ret.size);
       closedir (dir);
       return NULL;
     }
@@ -938,7 +937,6 @@ do_list_dm_devices (void)
   /* Did readdir fail? */
   if (errno != 0) {
     reply_with_perror ("readdir: /dev/mapper");
-    free_stringslen (ret.argv, ret.size);
     closedir (dir);
     return NULL;
   }
@@ -946,7 +944,6 @@ do_list_dm_devices (void)
   /* Close the directory handle. */
   if (closedir (dir) == -1) {
     reply_with_perror ("closedir: /dev/mapper");
-    free_stringslen (ret.argv, ret.size);
     return NULL;
   }
 
@@ -958,7 +955,7 @@ do_list_dm_devices (void)
   if (end_stringsbuf (&ret) == -1)
     return NULL;
 
-  return ret.argv;
+  return take_stringsbuf (&ret);
 }
 
 char *
