@@ -38,7 +38,7 @@ option_a (const char *arg, const char *format, struct drv **drvsp)
 
   drv = calloc (1, sizeof (struct drv));
   if (!drv) {
-    perror ("malloc");
+    perror ("calloc");
     exit (EXIT_FAILURE);
   }
 
@@ -84,7 +84,7 @@ option_d (const char *arg, struct drv **drvsp)
 
   drv = calloc (1, sizeof (struct drv));
   if (!drv) {
-    perror ("malloc");
+    perror ("calloc");
     exit (EXIT_FAILURE);
   }
 
@@ -105,7 +105,7 @@ add_drives_handle (guestfs_h *g, struct drv *drv, char next_drive)
   if (next_drive > 'z') {
     fprintf (stderr,
              _("%s: too many drives added on the command line\n"),
-             guestfs___program_name);
+             guestfs_int_program_name);
     exit (EXIT_FAILURE);
   }
 
@@ -269,19 +269,19 @@ display_mountpoints_on_failure (const char *mp_device,
     return;
 
   fprintf (stderr, _("%s: '%s' could not be mounted.\n"),
-           guestfs___program_name, mp_device);
+           guestfs_int_program_name, mp_device);
 
   if (user_supplied_options)
     fprintf (stderr, _("%s: Check mount(8) man page to ensure options '%s'\n"
                        "%s: are supported by the filesystem that is being mounted.\n"),
-             guestfs___program_name, user_supplied_options, guestfs___program_name);
+             guestfs_int_program_name, user_supplied_options, guestfs_int_program_name);
 
   fprintf (stderr, _("%s: Did you mean to mount one of these filesystems?\n"),
-           guestfs___program_name);
+           guestfs_int_program_name);
 
   for (i = 0; fses[i] != NULL; i += 2) {
     CLEANUP_FREE char *p = guestfs_canonical_device_name (g, fses[i]);
-    fprintf (stderr, "%s: \t%s (%s)\n", guestfs___program_name,
+    fprintf (stderr, "%s: \t%s (%s)\n", guestfs_int_program_name,
              p ? p : fses[i], fses[i+1]);
   }
 }
@@ -304,7 +304,7 @@ free_drives (struct drv *drv)
   case drv_uri:
     free (drv->uri.path);
     free (drv->uri.protocol);
-    guestfs___free_string_list (drv->uri.server);
+    guestfs_int_free_string_list (drv->uri.server);
     free (drv->uri.username);
     free (drv->uri.password);
     break;
@@ -340,6 +340,20 @@ free_mps (struct mp *mp)
   free (mp);
 }
 
+/* Implements the internal 'tool --short-options' flag, which just
+ * lists out the short options available.  Used by bash completion.
+ */
+void
+display_short_options (const char *format)
+{
+  while (*format) {
+    if (*format != ':')
+      printf ("-%c\n", *format);
+    ++format;
+  }
+  exit (EXIT_SUCCESS);
+}
+
 /* Implements the internal 'tool --long-options' flag, which just
  * lists out the long options available.  Used by bash completion.
  */
@@ -347,7 +361,7 @@ void
 display_long_options (const struct option *long_options)
 {
   while (long_options->name) {
-    if (STRNEQ (long_options->name, "long-options"))
+    if (STRNEQ (long_options->name, "long-options") && STRNEQ (long_options->name, "short-options"))
       printf ("--%s\n", long_options->name);
     long_options++;
   }
