@@ -103,7 +103,7 @@ main (int argc, char *argv[])
 
   enum { HELP_OPTION = CHAR_MAX + 1 };
 
-  static const char *options = "a:c:d:qvVx";
+  static const char options[] = "a:vVx";
   static const struct option long_options[] = {
     { "add", 1, 0, 'a' },
     { "filesystem", 1, 0, 0 },
@@ -226,14 +226,22 @@ main (int argc, char *argv[])
   assert (live == 0);
 
   /* Must be no extra arguments on the command line. */
-  if (optind != argc)
+  if (optind != argc) {
+    fprintf (stderr, _("%s: error: extra argument '%s' on command line.\n"
+             "Make sure to specify the argument for --format, --lvm "
+             "or --partition like '--format=%s'.\n"),
+             guestfs_int_program_name, argv[optind], argv[optind]);
     usage (EXIT_FAILURE);
+  }
 
   CHECK_OPTION_format_consumed;
 
   /* The user didn't specify any drives to format. */
-  if (drvs == NULL)
+  if (drvs == NULL) {
+    fprintf (stderr, _("%s: error: you must specify at least one -a option.\n"),
+             guestfs_int_program_name);
     usage (EXIT_FAILURE);
+  }
 
   /* Because the libguestfs kernel can get stuck rereading the
    * partition table after things have been erased, we sometimes need
