@@ -29,6 +29,8 @@ open Actions
 open Structs
 open Events
 
+let generate_header = generate_header ~inputs:["generator/c.ml"]
+
 (* Generate C API. *)
 
 (* The actions are split across this many C files.  You can increase
@@ -301,6 +303,12 @@ I<The caller must free the returned buffer after use>.\n\n"
     pr "This function takes a key or passphrase parameter which
 could contain sensitive material.  Read the section
 L</KEYS AND PASSPHRASES> for more information.\n\n";
+  (match f.optional with
+  | None -> ()
+  | Some opt ->
+    pr "This function depends on the feature C<%s>.  See also
+L</guestfs_feature_available>.\n\n" opt
+  );
   (match version_added f with
   | Some version -> pr "(Added in %s)\n\n" version
   | None -> assert false
@@ -1202,6 +1210,130 @@ and generate_client_structs_cleanup () =
 
   ) structs
 
+(* Generate structs-print.c file. *)
+and generate_client_structs_print_c () =
+  generate_header CStyle LGPLv2plus;
+
+  pr "\
+#include <config.h>
+
+#include <inttypes.h>
+
+#include \"c-ctype.h\"
+
+#include \"guestfs.h\"
+#include \"structs-print.h\"
+
+";
+
+  let write_structs =
+    List.iter (
+      fun { s_name = typ; s_cols = cols } ->
+        let needs_i =
+          List.exists (function (_, (FUUID|FBuffer)) -> true | _ -> false) cols in
+
+        pr "void\n";
+        pr "guestfs_int_print_%s_indent (struct guestfs_%s *%s, FILE *dest, const char *linesep, const char *indent)\n"
+          typ typ typ;
+        pr "{\n";
+        if needs_i then (
+          pr "  size_t i;\n";
+          pr "\n"
+        );
+        List.iter (
+          function
+          | name, FString ->
+              pr "  fprintf (dest, \"%%s%s: %%s%%s\", indent, %s->%s, linesep);\n"
+                name typ name
+          | name, FUUID ->
+              pr "  fprintf (dest, \"%%s%s: \", indent);\n" name;
+              pr "  for (i = 0; i < 32; ++i)\n";
+              pr "    fprintf (dest, \"%%c\", %s->%s[i]);\n" typ name;
+              pr "  fprintf (dest, \"%%s\", linesep);\n"
+          | name, FBuffer ->
+              pr "  fprintf (dest, \"%%s%s: \", indent);\n" name;
+              pr "  for (i = 0; i < %s->%s_len; ++i)\n" typ name;
+              pr "    if (c_isprint (%s->%s[i]))\n" typ name;
+              pr "      fprintf (dest, \"%%c\", %s->%s[i]);\n" typ name;
+              pr "    else\n";
+              pr "      fprintf (dest, \"\\\\x%%02x\", (unsigned) %s->%s[i]);\n"
+                 typ name;
+              pr "  fprintf (dest, \"%%s\", linesep);\n"
+          | name, (FUInt64|FBytes) ->
+              pr "  fprintf (dest, \"%%s%s: %%\" PRIu64 \"%%s\", indent, %s->%s, linesep);\n"
+                name typ name
+          | name, FInt64 ->
+              pr "  fprintf (dest, \"%%s%s: %%\" PRIi64 \"%%s\", indent, %s->%s, linesep);\n"
+                name typ name
+          | name, FUInt32 ->
+              pr "  fprintf (dest, \"%%s%s: %%\" PRIu32 \"%%s\", indent, %s->%s, linesep);\n"
+                name typ name
+          | name, FInt32 ->
+              pr "  fprintf (dest, \"%%s%s: %%\" PRIi32 \"%%s\", indent, %s->%s, linesep);\n"
+                name typ name
+          | name, FChar ->
+              pr "  fprintf (dest, \"%%s%s: %%c%%s\", indent, %s->%s, linesep);\n"
+                name typ name
+          | name, FOptPercent ->
+              pr "  if (%s->%s >= 0)\n" typ name;
+              pr "    fprintf (dest, \"%%s%s: %%g %%%%%%s\", indent, (double) %s->%s, linesep);\n"
+                name typ name;
+              pr "  else\n";
+              pr "    fprintf (dest, \"%%s%s: %%s\", indent, linesep);\n" name
+        ) cols;
+        pr "}\n";
+        pr "\n";
+    ) in
+
+  write_structs external_structs;
+
+  pr "\
+#if GUESTFS_PRIVATE
+
+";
+
+  write_structs internal_structs;
+
+  pr "\
+#endif /* End of GUESTFS_PRIVATE. */
+"
+
+(* Generate structs-print.h file. *)
+and generate_client_structs_print_h () =
+  generate_header CStyle LGPLv2plus;
+
+  pr "\
+#ifndef GUESTFS_INTERNAL_STRUCTS_PRINT_H_
+#define GUESTFS_INTERNAL_STRUCTS_PRINT_H_
+
+#include <stdio.h>
+
+";
+
+  let write_structs =
+    List.iter (
+      fun { s_name = name } ->
+        pr "extern void guestfs_int_print_%s_indent (struct guestfs_%s *%s, FILE *dest, const char *linesep, const char *indent);\n"
+          name name name
+    ) in
+
+  write_structs external_structs;
+
+  pr "\
+
+#if GUESTFS_PRIVATE
+
+";
+
+  write_structs internal_structs;
+
+  pr "\
+
+#endif /* End of GUESTFS_PRIVATE. */
+
+#endif /* GUESTFS_INTERNAL_STRUCTS_PRINT_H_ */
+"
+
 (* Generate the client-side dispatch stubs. *)
 and generate_client_actions hash () =
   generate_header CStyle LGPLv2plus;
@@ -1222,6 +1354,7 @@ and generate_client_actions hash () =
 #include \"guestfs-internal-actions.h\"
 #include \"guestfs_protocol.h\"
 #include \"errnostring.h\"
+#include \"structs-print.h\"
 
 ";
 
@@ -1497,7 +1630,7 @@ and generate_client_actions hash () =
 
     let needs_i =
       match ret with
-      | RStringList _ | RHashtable _ -> true
+      | RStringList _ | RHashtable _ | RStructList _ -> true
       | _ -> false in
     if needs_i then (
       pr "%s  size_t i;\n" indent;
@@ -1530,15 +1663,25 @@ and generate_client_actions hash () =
          pr "%s  }\n" indent;
          pr "%s  fputs (\"]\", trace_buffer.fp);\n" indent;
      | RStruct (_, typ) ->
-         (* XXX There is code generated for guestfish for printing
-          * these structures.  We need to make it generally available
-          * for all callers
-          *)
-         pr "%s  fprintf (trace_buffer.fp, \"<struct guestfs_%s *>\");\n"
-           indent typ (* XXX *)
+         pr "%s  fprintf (trace_buffer.fp, \"<struct guestfs_%s = \");\n"
+           indent typ;
+         pr "%s  guestfs_int_print_%s_indent (%s, trace_buffer.fp, \", \", \"\");\n"
+           indent typ rv;
+         pr "%s  fprintf (trace_buffer.fp, \">\");\n" indent
      | RStructList (_, typ) ->
-         pr "%s  fprintf (trace_buffer.fp, \"<struct guestfs_%s_list *>\");\n"
-           indent typ (* XXX *)
+         pr "%s  fprintf (trace_buffer.fp, \"<struct guestfs_%s_list(%%u)\", %s->len);\n"
+           indent typ rv;
+         pr "%s  if (%s->len > 0)\n" indent rv;
+         pr "%s    fprintf (trace_buffer.fp, \" = \");\n" indent;
+         pr "%s  for (i = 0; i < %s->len; ++i) {\n" indent rv;
+         pr "%s    if (i != 0)\n" indent;
+         pr "%s      fprintf (trace_buffer.fp, \" \");\n" indent;
+         pr "%s    fprintf (trace_buffer.fp, \"[%%zu]{\", i);\n" indent;
+         pr "%s    guestfs_int_print_%s_indent (&%s->val[i], trace_buffer.fp, \", \", \"\");\n"
+           indent typ rv;
+         pr "%s    fprintf (trace_buffer.fp, \"}\");\n" indent;
+         pr "%s  }\n" indent;
+         pr "%s  fprintf (trace_buffer.fp, \">\");\n" indent
     );
     pr "%s  guestfs_int_trace_send_line (g, &trace_buffer);\n" indent;
     pr "%s}\n" indent;
