@@ -389,7 +389,7 @@ and also for more keys for each user."
     op_discrim = "`Truncate";
     op_shortdesc = "Truncate a file to zero size";
     op_pod_longdesc = "\
-This command truncates \"path\" to a zero-length file. The file must exist
+This command truncates C<FILE> to a zero-length file. The file must exist
 already.";
   };
 
@@ -398,7 +398,7 @@ already.";
     op_discrim = "`TruncateRecursive";
     op_shortdesc = "Recursively truncate all files in directory";
     op_pod_longdesc = "\
-This command recursively truncates all files under \"path\" to zero-length.";
+This command recursively truncates all files under C<PATH> to zero-length.";
   };
 
   { op_name = "timezone";
@@ -421,7 +421,7 @@ This command performs a L<touch(1)>-like operation on C<FILE>.";
   { op_name = "update";
     op_type = Unit;
     op_discrim = "`Update";
-    op_shortdesc = "Update core packages";
+    op_shortdesc = "Update packages";
     op_pod_longdesc = "\
 Do the equivalent of C<yum update>, C<apt-get upgrade>, or whatever
 command is required to update the packages already installed in the
@@ -634,7 +634,7 @@ let rec argspec () =
         op_shortdesc = shortdesc; op_pod_longdesc = longdesc } ->
       pr "    (\n";
       pr "      \"--%s\",\n" name;
-      pr "      Arg.Unit (fun () -> ops := %s :: !ops),\n" discrim;
+      pr "      Arg.Unit (fun () -> push_front %s ops),\n" discrim;
       pr "      \" \" ^ s_\"%s\"\n" shortdesc;
       pr "    ),\n";
       pr "    None, %S;\n" longdesc
@@ -642,7 +642,7 @@ let rec argspec () =
         op_shortdesc = shortdesc; op_pod_longdesc = longdesc } ->
       pr "    (\n";
       pr "      \"--%s\",\n" name;
-      pr "      Arg.String (fun s -> ops := %s s :: !ops),\n" discrim;
+      pr "      Arg.String (fun s -> push_front (%s s) ops),\n" discrim;
       pr "      s_\"%s\" ^ \" \" ^ s_\"%s\"\n" v shortdesc;
       pr "    ),\n";
       pr "    Some %S, %S;\n" v longdesc
@@ -653,7 +653,7 @@ let rec argspec () =
       pr "      Arg.String (\n";
       pr "        fun s ->\n";
       pr "          let p = split_string_pair \"%s\" s in\n" name;
-      pr "          ops := %s p :: !ops\n" discrim;
+      pr "          push_front (%s p) ops\n" discrim;
       pr "      ),\n";
       pr "      s_\"%s\" ^ \" \" ^ s_\"%s\"\n" v shortdesc;
       pr "    ),\n";
@@ -665,7 +665,7 @@ let rec argspec () =
       pr "      Arg.String (\n";
       pr "        fun s ->\n";
       pr "          let ss = split_string_list s in\n";
-      pr "          ops := %s ss :: !ops\n" discrim;
+      pr "          push_front (%s ss) ops\n" discrim;
       pr "      ),\n";
       pr "      s_\"%s\" ^ \" \" ^ s_\"%s\"\n" v shortdesc;
       pr "    ),\n";
@@ -677,7 +677,7 @@ let rec argspec () =
       pr "      Arg.String (\n";
       pr "        fun s ->\n";
       pr "          let ss = split_links_list \"%s\" s in\n" name;
-      pr "          ops := %s ss :: !ops\n" discrim;
+      pr "          push_front (%s ss) ops\n" discrim;
       pr "      ),\n";
       pr "      s_\"%s\" ^ \" \" ^ s_\"%s\"\n" v shortdesc;
       pr "    ),\n";
@@ -689,7 +689,7 @@ let rec argspec () =
       pr "      Arg.String (\n";
       pr "        fun s ->\n";
       pr "          let sel = Password.parse_selector s in\n";
-      pr "          ops := %s sel :: !ops\n" discrim;
+      pr "          push_front (%s sel) ops\n" discrim;
       pr "      ),\n";
       pr "      s_\"%s\" ^ \" \" ^ s_\"%s\"\n" v shortdesc;
       pr "    ),\n";
@@ -702,7 +702,7 @@ let rec argspec () =
       pr "        fun s ->\n";
       pr "          let user, sel = split_string_pair \"%s\" s in\n" name;
       pr "          let sel = Password.parse_selector sel in\n";
-      pr "          ops := %s (user, sel) :: !ops\n" discrim;
+      pr "          push_front (%s (user, sel)) ops\n" discrim;
       pr "      ),\n";
       pr "      s_\"%s\" ^ \" \" ^ s_\"%s\"\n" v shortdesc;
       pr "    ),\n";
@@ -715,7 +715,7 @@ let rec argspec () =
       pr "        fun s ->\n";
       pr "          let user, selstr = String.split \":\" s in\n";
       pr "          let sel = Ssh_key.parse_selector selstr in\n";
-      pr "          ops := %s (user, sel) :: !ops\n" discrim;
+      pr "          push_front (%s (user, sel)) ops\n" discrim;
       pr "      ),\n";
       pr "      s_\"%s\" ^ \" \" ^ s_\"%s\"\n" v shortdesc;
       pr "    ),\n";
@@ -727,7 +727,7 @@ let rec argspec () =
       pr "      Arg.String (\n";
       pr "        fun s ->\n";
       pr "          %s s;\n" fn;
-      pr "          ops := %s s :: !ops\n" discrim;
+      pr "          push_front (%s s) ops\n" discrim;
       pr "      ),\n";
       pr "      s_\"%s\" ^ \" \" ^ s_\"%s\"\n" v shortdesc;
       pr "    ),\n";
@@ -739,7 +739,7 @@ let rec argspec () =
       pr "      Arg.String (\n";
       pr "        fun s ->\n";
       pr "          let sel = Subscription_manager.parse_pool_selector s in\n";
-      pr "          ops := %s sel :: !ops\n" discrim;
+      pr "          push_front (%s sel) ops\n" discrim;
       pr "      ),\n";
       pr "      s_\"%s\" ^ \" \" ^ s_\"%s\"\n" v shortdesc;
       pr "    ),\n";
