@@ -27,7 +27,7 @@ let parse_cmdline () =
   let domain = ref None in
   let file = ref None in
   let libvirturi = ref "" in
-  let format = ref "" in
+  let format = ref "auto" in
   let output = ref "" in
   let machine_readable = ref false in
   let unversioned = ref false in
@@ -107,7 +107,7 @@ read the man page virt-get-kernel(1).
         let { URI.path = path; protocol = protocol;
               server = server; username = username;
               password = password } = uri in
-        let format = match !format with "" -> None | s -> Some s in
+        let format = match !format with "auto" -> None | s -> Some s in
         g#add_drive
           ~readonly:true ?format ~protocol ?server ?username ?secret:password
           path
