@@ -50,7 +50,7 @@ static const char *format = "raw", *label = NULL,
   *partition = NULL, *size_str = NULL, *type = "ext2";
 
 enum { HELP_OPTION = CHAR_MAX + 1 };
-static const char *options = "F:s:t:Vvx";
+static const char options[] = "F:s:t:Vvx";
 static const struct option long_options[] = {
   { "debug", 0, 0, 'v' }, /* for compat with Perl tool */
   { "floppy", 0, 0, 0 },
@@ -81,16 +81,16 @@ usage (int status)
               "  %s [--options] input.tar.gz output.img\n"
               "  %s [--options] directory output.img\n"
               "Options:\n"
-              "  --floppy               Make a virtual floppy disk\n"
-              "  --format=raw|qcow2|..  Set output format\n"
-              "  --help                 Display brief help\n"
-              "  --label=label          Filesystem label\n"
-              "  --partition=mbr|gpt|.. Set partition type\n"
-              "  --size=size|+size      Set size of output disk\n"
-              "  --type=ext4|..         Set filesystem type\n"
-              "  -v|--verbose           Verbose messages\n"
-              "  -V|--version           Display version and exit\n"
-              "  -x                     Trace libguestfs API calls\n"
+              "  --floppy                 Make a virtual floppy disk\n"
+              "  -F|--format=raw|qcow2|.. Set output format\n"
+              "  --help                   Display brief help\n"
+              "  --label=label            Filesystem label\n"
+              "  --partition=mbr|gpt|..   Set partition type\n"
+              "  -s|--size=size|+size     Set size of output disk\n"
+              "  -t|--type=ext4|..        Set filesystem type\n"
+              "  -v|--verbose             Verbose messages\n"
+              "  -V|--version             Display version and exit\n"
+              "  -x                       Trace libguestfs API calls\n"
               "For more information, see the manpage %s(1).\n"),
             guestfs_int_program_name, guestfs_int_program_name,
             guestfs_int_program_name, guestfs_int_program_name,
