@@ -1,5 +1,5 @@
 /* libguestfs
- * Copyright (C) 2009-2013 Red Hat Inc.
+ * Copyright (C) 2009-2016 Red Hat Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,11 +22,10 @@
 #include "guestfs-internal-frontend.h"
 
 #define Guestfs_val(v) (*((guestfs_h **)Data_custom_val(v)))
-extern void ocaml_guestfs_raise_error (guestfs_h *g, const char *func)
+extern void guestfs_int_ocaml_raise_error (guestfs_h *g, const char *func)
   Noreturn;
-extern void ocaml_guestfs_raise_closed (const char *func)
+extern void guestfs_int_ocaml_raise_closed (const char *func)
   Noreturn;
-extern char **ocaml_guestfs_strings_val (guestfs_h *g, value sv);
-extern void ocaml_guestfs_free_strings (char **r);
+extern char **guestfs_int_ocaml_strings_val (guestfs_h *g, value sv);
 
 #endif /* GUESTFS_OCAML_C_H */
