@@ -35,22 +35,26 @@
 #pragma GCC diagnostic ignored "-Wstrict-prototypes" /* error in <gtk.h> */
 #include <gtk/gtk.h>
 
+#include "ignore-value.h"
 #include "p2v.h"
 
 char **all_disks;
 char **all_removable;
 char **all_interfaces;
+int is_iso_environment = 0;
 
+static void udevadm_settle (void);
 static void set_config_defaults (struct config *config);
 static void find_all_disks (void);
 static void find_all_interfaces (void);
 static int cpuinfo_flags (void);
 
 enum { HELP_OPTION = CHAR_MAX + 1 };
-static const char *options = "Vv";
+static const char options[] = "Vv";
 static const struct option long_options[] = {
   { "help", 0, 0, HELP_OPTION },
   { "cmdline", 1, 0, 0 },
+  { "iso", 0, 0, 0 },
   { "long-options", 0, 0, 0 },
   { "short-options", 0, 0, 0 },
   { "verbose", 0, 0, 'v' },
@@ -72,6 +76,7 @@ usage (int status)
               "Options:\n"
               "  --help                 Display brief help\n"
               " --cmdline=CMDLINE       Used to debug command line parsing\n"
+              " --iso                   Running in the ISO environment\n"
               "  -v|--verbose           Verbose messages\n"
               "  -V|--version           Display version and exit\n"
               "For more information, see the manpage %s(1).\n"),
@@ -118,6 +123,13 @@ main (int argc, char *argv[])
   bindtextdomain (PACKAGE, LOCALEBASEDIR);
   textdomain (PACKAGE);
 
+  /* There is some raciness between slow devices being discovered by
+   * the kernel and udev and virt-p2v running.  This is a partial
+   * workaround, but a real fix involves handling hotplug events
+   * (possible in GUI mode, not easy in kernel mode).
+   */
+  udevadm_settle ();
+
 #if ! GLIB_CHECK_VERSION(2,32,0)
   /* In glib2 < 2.32 you had to call g_thread_init().  In later glib2
    * that is not required and should not be called.
@@ -145,6 +157,9 @@ main (int argc, char *argv[])
         cmdline = parse_cmdline_string (optarg);
         cmdline_source = CMDLINE_SOURCE_COMMAND_LINE;
       }
+      else if (STREQ (long_options[option_index].name, "iso")) {
+        is_iso_environment = 1;
+      }
       else {
         fprintf (stderr, _("%s: unknown long option: %s (%d)\n"),
                  guestfs_int_program_name, long_options[option_index].name, option_index);
@@ -157,9 +172,7 @@ main (int argc, char *argv[])
       break;
 
     case 'V':
-      printf ("%s %s%s\n",
-              guestfs_int_program_name,
-              PACKAGE_VERSION, PACKAGE_VERSION_EXTRA);
+      printf ("%s %s\n", guestfs_int_program_name, PACKAGE_VERSION_FULL);
       exit (EXIT_SUCCESS);
 
     case HELP_OPTION:
@@ -212,6 +225,12 @@ main (int argc, char *argv[])
   exit (EXIT_SUCCESS);
 }
 
+static void
+udevadm_settle (void)
+{
+  ignore_value (system ("udevadm settle"));
+}
+
 static void
 set_config_defaults (struct config *config)
 {
@@ -229,7 +248,7 @@ set_config_defaults (struct config *config)
     perror ("gethostname");
     /* Generate a simple random name. */
     if (guestfs_int_random_string (hostname, 8) == -1) {
-      perror ("/dev/urandom");
+      perror ("guestfs_int_random_string");
       exit (EXIT_FAILURE);
     }
   } else {
