@@ -56,9 +56,7 @@
 #include "miniexpect.h"
 #include "p2v.h"
 
-int v2v_major;
-int v2v_minor;
-int v2v_release;
+char *v2v_version = NULL;
 char **input_drivers = NULL;
 char **output_drivers = NULL;
 
@@ -138,14 +136,14 @@ compile_regexps (void)
     CHECK_PARTIAL_OK ((pattern), re);					\
   } while (0)
 
-  COMPILE (password_re, "assword", 0);
+  COMPILE (password_re, "password:", 0);
   /* The magic synchronization strings all match this expression.  See
    * start_ssh function below.
    */
   COMPILE (prompt_re,
 	   "###((?:[0123456789abcdefghijklmnopqrstuvwxyz]){8})### ", 0);
   COMPILE (version_re,
-           "virt-v2v ([1-9](?:\\d)*)\\.([1-9](?:\\d)*)\\.(0|[1-9](?:\\d)*)",
+           "virt-v2v ([1-9].*)",
 	   0);
   COMPILE (feature_libguestfs_rewrite_re, "libguestfs-rewrite", 0);
   COMPILE (feature_input_re, "input:((?:\\w)*)", 0);
@@ -334,8 +332,10 @@ start_ssh (struct config *config, char **extra_args, int wait_prompt)
   assert (j == nr_args);
 
   h = mexp_spawnv ("ssh", (char **) args);
-  if (h == NULL)
+  if (h == NULL) {
+    set_ssh_error ("internal error: ssh: mexp_spawnv: %m");
     return NULL;
+  }
 
   if (using_password_auth &&
       config->password && strlen (config->password) > 0) {
@@ -417,12 +417,9 @@ start_ssh (struct config *config, char **extra_args, int wait_prompt)
                            { 0 }
                          }, ovector, ovecsize)) {
     case 100:                    /* Got password prompt unexpectedly. */
-      if (mexp_printf (h, "%s\n", config->password) == -1) {
-        mexp_close (h);
-        set_ssh_error ("unexpected password prompt: probably the password supplied is wrong");
-        return NULL;
-      }
-      break;
+      mexp_close (h);
+      set_ssh_error ("login failed - probably the username and/or password is wrong");
+      return NULL;
 
     case 101:
       /* Got a prompt.  However it might be an earlier prompt.  If it
@@ -475,6 +472,7 @@ start_ssh (struct config *config, char **extra_args, int wait_prompt)
 
 static void add_input_driver (const char *name, size_t len);
 static void add_output_driver (const char *name, size_t len);
+static int compatible_version (const char *v2v_version);
 
 #pragma GCC diagnostic ignored "-Wsuggest-attribute=noreturn" /* WTF? */
 int
@@ -494,14 +492,15 @@ test_connection (struct config *config)
   /* Clear any previous version information since we may be connecting
    * to a different server.
    */
-  v2v_major = v2v_minor = v2v_release = 0;
+  free (v2v_version);
+  v2v_version = NULL;
 
   /* Send 'virt-v2v --version' command and hope we get back a version string.
    * Note old virt-v2v did not understand -V option.
    */
   if (mexp_printf (h,
                    "%svirt-v2v --version\n",
-                   config->sudo ? "sudo " : "") == -1) {
+                   config->sudo ? "sudo -n " : "") == -1) {
     set_ssh_error ("mexp_printf: %m");
     mexp_close (h);
     return -1;
@@ -515,24 +514,12 @@ test_connection (struct config *config)
                            { 0 }
                          }, ovector, ovecsize)) {
     case 100:                   /* Got version string. */
-      major_str = strndup (&h->buffer[ovector[2]], ovector[3]-ovector[2]);
-      minor_str = strndup (&h->buffer[ovector[4]], ovector[5]-ovector[4]);
-      release_str = strndup (&h->buffer[ovector[6]], ovector[7]-ovector[6]);
-      sscanf (major_str, "%d", &v2v_major);
-      sscanf (minor_str, "%d", &v2v_minor);
-      sscanf (release_str, "%d", &v2v_release);
+      free (v2v_version);
+      v2v_version = strndup (&h->buffer[ovector[2]], ovector[3]-ovector[2]);
 #if DEBUG_STDERR
-      fprintf (stderr, "%s: remote virt-v2v version: %d.%d.%d\n",
-               guestfs_int_program_name, v2v_major, v2v_minor, v2v_release);
+      fprintf (stderr, "%s: remote virt-v2v version: %s\n",
+               guestfs_int_program_name, v2v_version);
 #endif
-      /* This is an internal error.  Need to check this here so we
-       * don't confuse it with the no-version case below.
-       */
-      if (v2v_major < 1) {
-        mexp_close (h);
-        set_ssh_error ("could not parse version string");
-        return -1;
-      }
       break;
 
     case 101:             /* Got the prompt. */
@@ -562,31 +549,16 @@ test_connection (struct config *config)
  end_of_version:
 
   /* Got the prompt but no version number. */
-  if (v2v_major == 0) {
+  if (v2v_version == NULL) {
     mexp_close (h);
     set_ssh_error ("virt-v2v is not installed on the conversion server, "
                    "or it might be a too old version");
     return -1;
   }
 
-  /* The major version must always be 1. */
-  if (v2v_major != 1) {
+  /* Check the version of virt-v2v is compatible with virt-p2v. */
+  if (!compatible_version (v2v_version)) {
     mexp_close (h);
-    set_ssh_error ("virt-v2v major version is not 1 (major = %d), "
-                   "this version of virt-p2v is not compatible", v2v_major);
-    return -1;
-  }
-
-  /* The version of virt-v2v must be >= 1.28, just to make sure
-   * someone isn't (a) using one of the experimental 1.27 releases
-   * that we published during development, nor (b) using old virt-v2v.
-   * We should remain compatible with any virt-v2v after 1.28.
-   */
-  if (v2v_minor < 28) {
-    mexp_close (h);
-    set_ssh_error ("virt-v2v version is < 1.28 (major = %d, minor = %d), "
-                   "you must upgrade to virt-v2v >= 1.28 on "
-                   "the conversion server", v2v_major, v2v_minor);
     return -1;
   }
 
@@ -599,7 +571,7 @@ test_connection (struct config *config)
 
   /* Get virt-v2v features.  See: v2v/cmdline.ml */
   if (mexp_printf (h, "%svirt-v2v --machine-readable\n",
-                   config->sudo ? "sudo " : "") == -1) {
+                   config->sudo ? "sudo -n " : "") == -1) {
     set_ssh_error ("mexp_printf: %m");
     mexp_close (h);
     return -1;
@@ -748,6 +720,40 @@ add_output_driver (const char *name, size_t len)
     add_option ("output", &output_drivers, name, len);
 }
 
+static int
+compatible_version (const char *v2v_version)
+{
+  unsigned v2v_minor;
+
+  /* The major version must always be 1. */
+  if (!STRPREFIX (v2v_version, "1.")) {
+    set_ssh_error ("virt-v2v major version is not 1 (\"%s\"), "
+                   "this version of virt-p2v is not compatible",
+                   v2v_version);
+    return 0;
+  }
+
+  /* The version of virt-v2v must be >= 1.28, just to make sure
+   * someone isn't (a) using one of the experimental 1.27 releases
+   * that we published during development, nor (b) using old virt-v2v.
+   * We should remain compatible with any virt-v2v after 1.28.
+   */
+  if (sscanf (v2v_version, "1.%u", &v2v_minor) != 1) {
+    set_ssh_error ("cannot parse virt-v2v version string (\"%s\")",
+                   v2v_version);
+    return 0;
+  }
+
+  if (v2v_minor < 28) {
+    set_ssh_error ("virt-v2v version is < 1.28 (\"%s\"), "
+                   "you must upgrade to virt-v2v >= 1.28 on "
+                   "the conversion server", v2v_version);
+    return 0;
+  }
+
+  return 1;                     /* compatible */
+}
+
 /* The p2v ISO should allow us to open up just about any port. */
 static int nbd_local_port = 50123;
 
