@@ -1,5 +1,5 @@
 /* libguestfs
- * Copyright (C) 2009-2014 Red Hat Inc.
+ * Copyright (C) 2009-2016 Red Hat Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,20 +22,16 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdint.h>
-#include <string.h>
-#include <unistd.h>
 
 #include "guestfs.h"
 #include "guestfs-internal.h"
-#include "guestfs-internal-actions.h"
 #include "guestfs_protocol.h"
 
 /* Check the return message from a call for validity. */
 int
-guestfs___check_reply_header (guestfs_h *g,
-                              const struct guestfs_message_header *hdr,
-                              unsigned int proc_nr, unsigned int serial)
+guestfs_int_check_reply_header (guestfs_h *g,
+				const struct guestfs_message_header *hdr,
+				unsigned int proc_nr, unsigned int serial)
 {
   if (hdr->prog != GUESTFS_PROGRAM) {
     error (g, "wrong program (%u/%d)", hdr->prog, GUESTFS_PROGRAM);
@@ -65,7 +61,7 @@ guestfs___check_reply_header (guestfs_h *g,
 
 /* Check the appliance is up when running a daemon_function. */
 int
-guestfs___check_appliance_up (guestfs_h *g, const char *caller)
+guestfs_int_check_appliance_up (guestfs_h *g, const char *caller)
 {
   if (g->state == CONFIG || g->state == LAUNCHING) {
     error (g, "%s: call launch before using this function\n(in guestfish, don't forget to use the 'run' command)",
@@ -77,7 +73,7 @@ guestfs___check_appliance_up (guestfs_h *g, const char *caller)
 
 /* Convenience wrapper for tracing. */
 void
-guestfs___trace_open (struct trace_buffer *tb)
+guestfs_int_trace_open (struct trace_buffer *tb)
 {
   tb->buf = NULL;
   tb->len = 0;
@@ -94,12 +90,12 @@ guestfs___trace_open (struct trace_buffer *tb)
 }
 
 void
-guestfs___trace_send_line (guestfs_h *g, struct trace_buffer *tb)
+guestfs_int_trace_send_line (guestfs_h *g, struct trace_buffer *tb)
 {
   if (tb->opened) {
     fclose (tb->fp);
     tb->fp = NULL;
-    guestfs___call_callbacks_message (g, GUESTFS_EVENT_TRACE, tb->buf, tb->len);
+    guestfs_int_call_callbacks_message (g, GUESTFS_EVENT_TRACE, tb->buf, tb->len);
     free (tb->buf);
     tb->buf = NULL;
   }
