@@ -1,5 +1,5 @@
 /* libguestfs
- * Copyright (C) 2009-2014 Red Hat Inc.
+ * Copyright (C) 2009-2016 Red Hat Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,15 +23,11 @@
 #include <unistd.h>
 #include <string.h>
 
-#include <libxml/tree.h>
-#include <libxml/xpath.h>
-#include <libxml/xmlwriter.h>
-
 #include "guestfs.h"
 #include "guestfs-internal.h"
 
 void *
-guestfs___safe_malloc (guestfs_h *g, size_t nbytes)
+guestfs_int_safe_malloc (guestfs_h *g, size_t nbytes)
 {
   void *ptr = malloc (nbytes);
   if (nbytes > 0 && !ptr) g->abort_cb ();
@@ -50,8 +46,8 @@ guestfs___safe_malloc (guestfs_h *g, size_t nbytes)
    sizeof (ptrdiff_t) <= sizeof (size_t), so do not bother to test for
    exactly-SIZE_MAX allocations on such hosts; this avoids a test and
    branch when S is known to be 1.  */
-# define xalloc_oversized(n, s) \
-    ((size_t) (sizeof (ptrdiff_t) <= sizeof (size_t) ? -1 : -2) / (s) < (n))
+# define xalloc_oversized(n, s)						\
+  ((size_t) (sizeof (ptrdiff_t) <= sizeof (size_t) ? -1 : -2) / (s) < (n))
 
 /* Technically we should add an autoconf test for this, testing for the desired
    functionality, like what's done in gnulib, but for now, this is fine.  */
@@ -64,7 +60,7 @@ guestfs___safe_malloc (guestfs_h *g, size_t nbytes)
 /* Allocate zeroed memory for N elements of S bytes, with error
    checking.  S must be nonzero.  */
 void *
-guestfs___safe_calloc (guestfs_h *g, size_t n, size_t s)
+guestfs_int_safe_calloc (guestfs_h *g, size_t n, size_t s)
 {
   /* From gnulib's calloc function in xmalloc.c.  */
   void *p;
@@ -79,7 +75,7 @@ guestfs___safe_calloc (guestfs_h *g, size_t n, size_t s)
 }
 
 void *
-guestfs___safe_realloc (guestfs_h *g, void *ptr, size_t nbytes)
+guestfs_int_safe_realloc (guestfs_h *g, void *ptr, size_t nbytes)
 {
   void *p = realloc (ptr, nbytes);
   if (nbytes > 0 && !p) g->abort_cb ();
@@ -87,7 +83,7 @@ guestfs___safe_realloc (guestfs_h *g, void *ptr, size_t nbytes)
 }
 
 char *
-guestfs___safe_strdup (guestfs_h *g, const char *str)
+guestfs_int_safe_strdup (guestfs_h *g, const char *str)
 {
   char *s = strdup (str);
   if (!s) g->abort_cb ();
@@ -95,7 +91,7 @@ guestfs___safe_strdup (guestfs_h *g, const char *str)
 }
 
 char *
-guestfs___safe_strndup (guestfs_h *g, const char *str, size_t n)
+guestfs_int_safe_strndup (guestfs_h *g, const char *str, size_t n)
 {
   char *s = strndup (str, n);
   if (!s) g->abort_cb ();
@@ -103,7 +99,7 @@ guestfs___safe_strndup (guestfs_h *g, const char *str, size_t n)
 }
 
 void *
-guestfs___safe_memdup (guestfs_h *g, const void *ptr, size_t size)
+guestfs_int_safe_memdup (guestfs_h *g, const void *ptr, size_t size)
 {
   void *p = malloc (size);
   if (!p) g->abort_cb ();
@@ -112,7 +108,7 @@ guestfs___safe_memdup (guestfs_h *g, const void *ptr, size_t size)
 }
 
 char *
-guestfs___safe_asprintf (guestfs_h *g, const char *fs, ...)
+guestfs_int_safe_asprintf (guestfs_h *g, const char *fs, ...)
 {
   va_list args;
   char *msg;
