@@ -402,9 +402,15 @@ create_drive_dev_null (guestfs_h *g,
 {
   CLEANUP_FREE char *tmpfile = NULL;
 
-  if (data->format && STRNEQ (data->format, "raw")) {
-    error (g, _("for device '/dev/null', format must be 'raw'"));
-    return NULL;
+  if (data->format) {
+    if (STRNEQ (data->format, "raw")) {
+      error (g, _("for device '/dev/null', format must be 'raw'"));
+      return NULL;
+    }
+  } else {
+    /* Manual set format=raw for /dev/null drives, if that was not
+     * already manually specified.  */
+    data->format = "raw";
   }
 
   if (guestfs_int_lazy_make_tmpdir (g) == -1)
@@ -693,7 +699,7 @@ parse_servers (guestfs_h *g, char *const *strs,
                struct drive_server **servers_rtn)
 {
   size_t i;
-  size_t n = guestfs_int_count_strings (strs);
+  const size_t n = guestfs_int_count_strings (strs);
   struct drive_server *servers;
 
   if (n == 0) {
