@@ -152,9 +152,9 @@ check_filesystem (guestfs_h *g, const char *mountable,
   fs->mountable = safe_strdup (g, mountable);
 
   /* Optimize some of the tests by avoiding multiple tests of the same thing. */
-  int is_dir_etc = guestfs_is_dir (g, "/etc") > 0;
-  int is_dir_bin = guestfs_is_dir (g, "/bin") > 0;
-  int is_dir_share = guestfs_is_dir (g, "/share") > 0;
+  const int is_dir_etc = guestfs_is_dir (g, "/etc") > 0;
+  const int is_dir_bin = guestfs_is_dir (g, "/bin") > 0;
+  const int is_dir_share = guestfs_is_dir (g, "/share") > 0;
 
   /* Grub /boot? */
   if (guestfs_is_file (g, "/grub/menu.lst") > 0 ||
@@ -217,7 +217,8 @@ check_filesystem (guestfs_h *g, const char *mountable,
   else if (is_dir_etc &&
            (is_dir_bin ||
             is_symlink_to (g, "/bin", "usr/bin") > 0) &&
-           guestfs_is_file (g, "/etc/fstab") > 0) {
+           (guestfs_is_file (g, "/etc/fstab") > 0 ||
+            guestfs_is_file (g, "/etc/hosts") > 0)) {
     fs->is_root = 1;
     fs->format = OS_FORMAT_INSTALLED;
     if (guestfs_int_check_linux_root (g, fs) == -1)
@@ -325,7 +326,7 @@ check_filesystem (guestfs_h *g, const char *mountable,
 static void
 extend_fses (guestfs_h *g)
 {
-  size_t n = g->nr_fses + 1;
+  const size_t n = g->nr_fses + 1;
   struct inspect_fs *p;
 
   p = safe_realloc (g, g->fses, n * sizeof (struct inspect_fs));
@@ -413,7 +414,7 @@ int
 guestfs_int_parse_unsigned_int (guestfs_h *g, const char *str)
 {
   long ret;
-  int r = xstrtol (str, NULL, 10, &ret, "");
+  const int r = xstrtol (str, NULL, 10, &ret, "");
   if (r != LONGINT_OK) {
     error (g, _("could not parse integer in version number: %s"), str);
     return -1;
@@ -426,7 +427,7 @@ int
 guestfs_int_parse_unsigned_int_ignore_trailing (guestfs_h *g, const char *str)
 {
   long ret;
-  int r = xstrtol (str, NULL, 10, &ret, NULL);
+  const int r = xstrtol (str, NULL, 10, &ret, NULL);
   if (r != LONGINT_OK) {
     error (g, _("could not parse integer in version number: %s"), str);
     return -1;
@@ -531,8 +532,11 @@ guestfs_int_check_package_management (guestfs_h *g, struct inspect_fs *fs)
         guestfs_is_file_opts (g, "/usr/bin/dnf",
                               GUESTFS_IS_FILE_OPTS_FOLLOWSYMLINKS, 1, -1) > 0)
       fs->package_management = OS_PACKAGE_MANAGEMENT_DNF;
-    else
+    else if (fs->major_version >= 1)
       fs->package_management = OS_PACKAGE_MANAGEMENT_YUM;
+    else
+      /* Probably parsing the release file failed, see RHBZ#1332025. */
+      fs->package_management = OS_PACKAGE_MANAGEMENT_UNKNOWN;
     break;
 
   case OS_DISTRO_REDHAT_BASED:
@@ -542,8 +546,11 @@ guestfs_int_check_package_management (guestfs_h *g, struct inspect_fs *fs)
   case OS_DISTRO_ORACLE_LINUX:
     if (fs->major_version >= 5)
       fs->package_management = OS_PACKAGE_MANAGEMENT_YUM;
-    else
+    else if (fs->major_version >= 2)
       fs->package_management = OS_PACKAGE_MANAGEMENT_UP2DATE;
+    else
+      /* Probably parsing the release file failed, see RHBZ#1332025. */
+      fs->package_management = OS_PACKAGE_MANAGEMENT_UNKNOWN;
     break;
 
   case OS_DISTRO_DEBIAN:
