@@ -255,11 +255,11 @@ let rec convert ~keep_serial_console (g : G.guestfs) inspect source =
     ) inspect.i_apps in
 
   if verbose () then (
-    printf "installed kernel packages in this guest:\n";
+    eprintf "installed kernel packages in this guest:\n";
     List.iter (
-      fun kernel -> printf "\t%s\n" (string_of_kernel_info kernel)
+      fun kernel -> eprintf "\t%s\n" (string_of_kernel_info kernel)
     ) installed_kernels;
-    flush stdout
+    flush stderr
   );
 
   if installed_kernels = [] then
@@ -375,11 +375,11 @@ let rec convert ~keep_serial_console (g : G.guestfs) inspect source =
     ) vmlinuzes in
 
   if verbose () then (
-    printf "grub kernels in this guest (first in list is default):\n";
+    eprintf "grub kernels in this guest (first in list is default):\n";
     List.iter (
-      fun kernel -> printf "\t%s\n" (string_of_kernel_info kernel)
+      fun kernel -> eprintf "\t%s\n" (string_of_kernel_info kernel)
     ) grub_kernels;
-    flush stdout
+    flush stderr
   );
 
   if grub_kernels = [] then
@@ -516,7 +516,7 @@ let rec convert ~keep_serial_console (g : G.guestfs) inspect source =
         fun line ->
           if Str.string_match rex line 0 then (
             let path = Str.matched_group 1 line in
-            let path = Linux.shell_unquote path in
+            let path = Utils.shell_unquote path in
             if String.length path >= 1 && path.[0] = '/' then (
               let vboxuninstall = path ^ "/uninstall.sh" in
               Some vboxuninstall
@@ -556,13 +556,13 @@ let rec convert ~keep_serial_console (g : G.guestfs) inspect source =
     List.iter (
       fun { G.app2_name = name } ->
         if String.is_prefix name "vmware-tools-libraries-" then
-          libraries := name :: !libraries
+          push_front name libraries
         else if String.is_prefix name "vmware-tools-" then
-          remove := name :: !remove
+          push_front name remove
         else if name = "VMwareTools" then
-          remove := name :: !remove
+          push_front name remove
         else if String.is_prefix name "kmod-vmware-tools" then
-          remove := name :: !remove
+          push_front name remove
     ) inspect.i_apps;
     let libraries = !libraries in
 
@@ -602,7 +602,7 @@ let rec convert ~keep_serial_console (g : G.guestfs) inspect source =
             let cmd = Array.of_list cmd in
             (try
                ignore (g#command cmd);
-               remove := library :: !remove
+               push_front library remove
              with G.Error msg ->
                eprintf "%s: could not install replacement for %s.  Error was: %s.  %s was not removed.\n"
                  prog library msg library
@@ -1050,9 +1050,9 @@ let rec convert ~keep_serial_console (g : G.guestfs) inspect source =
       if Str.string_match rex grub_cmdline 0 then (
         let new_grub_cmdline =
           if not remove then
-            Str.global_replace rex "\\1console=ttyS0\\3" grub_cmdline
+            Str.global_replace rex "\\1console=ttyS0\\2" grub_cmdline
           else
-            Str.global_replace rex "\\1\\3" grub_cmdline in
+            Str.global_replace rex "\\1\\2" grub_cmdline in
         g#aug_set path new_grub_cmdline;
         g#aug_save ();
 
@@ -1192,28 +1192,18 @@ let rec convert ~keep_serial_console (g : G.guestfs) inspect source =
 
   and discover_modpath () =
     (* Find what /etc/modprobe.conf is called today. *)
-    let modpath = ref "" in
-
-    (* Note that we're checking in ascending order of preference so
-     * that the last discovered method will be chosen.
-     *)
-    List.iter (
-      fun file ->
-        if g#is_file ~followsymlinks:true file then
-          modpath := file
-    ) [ "/etc/conf.modules"; "/etc/modules.conf" ];
-
-    if g#is_file ~followsymlinks:true "/etc/modprobe.conf" then
-      modpath := "modprobe.conf";
-
-    if g#is_dir ~followsymlinks:true "/etc/modprobe.d" then
+    if g#is_dir ~followsymlinks:true "/etc/modprobe.d" then (
       (* Create a new file /etc/modprobe.d/virt-v2v-added.conf. *)
-      modpath := "modprobe.d/virt-v2v-added.conf";
+      "/etc/modprobe.d/virt-v2v-added.conf"
+    ) else (
+      (* List of methods, in order of preference. *)
+      let paths = [ "/etc/modprobe.conf"; "/etc/modules.conf"; "/etc/conf.modules" ] in
 
-    if !modpath = "" then
-      error (f_"unable to find any valid modprobe configuration file such as /etc/modprobe.conf");
-
-    !modpath
+      try
+        List.find (g#is_file ~followsymlinks:true) paths
+      with Not_found ->
+        error (f_"unable to find any valid modprobe configuration file such as /etc/modprobe.conf");
+    )
 
   and remap_block_devices virtio =
     (* This function's job is to iterate over boot configuration
@@ -1271,12 +1261,12 @@ let rec convert ~keep_serial_console (g : G.guestfs) inspect source =
       ) source.s_disks in
 
     if verbose () then (
-      printf "block device map:\n";
+      eprintf "block device map:\n";
       List.iter (
         fun (source_dev, target_dev) ->
-          printf "\t%s\t-> %s\n" source_dev target_dev
+          eprintf "\t%s\t-> %s\n" source_dev target_dev
       ) (List.sort (fun (a,_) (b,_) -> compare a b) map);
-      flush stdout
+      flush stderr
     );
 
     (* Possible Augeas paths to search for device names. *)
