@@ -1,5 +1,5 @@
 (* virt-v2v
- * Copyright (C) 2009-2014 Red Hat Inc.
+ * Copyright (C) 2009-2016 Red Hat Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 (** [-o local] target. *)
 
-val output_local : bool -> string -> Types.output
-(** [output_local verbose filename] creates and returns a new
+val output_local : string -> Types.output
+(** [output_local filename] creates and returns a new
     {!Types.output} object specialized for writing output to local
     files. *)
