@@ -164,116 +164,116 @@ let test_virtio_iso_path_matches_guest_os ctx =
 
   let paths = [
     (* Paths from the virtio-win 1.7.4 ISO. *)
-    "Balloon/2k12/amd64/WdfCoInstaller01011.dll", None;
+    "Balloon/2k12/amd64/WdfCoInstaller01011.dll", Some win2k12_64;
     "Balloon/2k12/amd64/balloon.cat", Some win2k12_64;
     "Balloon/2k12/amd64/balloon.inf", Some win2k12_64;
     "Balloon/2k12/amd64/balloon.pdb", Some win2k12_64;
     "Balloon/2k12/amd64/balloon.sys", Some win2k12_64;
-    "Balloon/2k12/amd64/blnsvr.exe", None;
+    "Balloon/2k12/amd64/blnsvr.exe", Some win2k12_64;
     "Balloon/2k12/amd64/blnsvr.pdb", Some win2k12_64;
-    "Balloon/2k12R2/amd64/WdfCoInstaller01011.dll", None;
+    "Balloon/2k12R2/amd64/WdfCoInstaller01011.dll", Some win2k12r2_64;
     "Balloon/2k12R2/amd64/balloon.cat", Some win2k12r2_64;
     "Balloon/2k12R2/amd64/balloon.inf", Some win2k12r2_64;
     "Balloon/2k12R2/amd64/balloon.pdb", Some win2k12r2_64;
     "Balloon/2k12R2/amd64/balloon.sys", Some win2k12r2_64;
-    "Balloon/2k12R2/amd64/blnsvr.exe", None;
+    "Balloon/2k12R2/amd64/blnsvr.exe", Some win2k12r2_64;
     "Balloon/2k12R2/amd64/blnsvr.pdb", Some win2k12r2_64;
-    "Balloon/2k3/amd64/WdfCoInstaller01009.dll", None;
+    "Balloon/2k3/amd64/WdfCoInstaller01009.dll", Some win2k3_64;
     "Balloon/2k3/amd64/balloon.cat", Some win2k3_64;
     "Balloon/2k3/amd64/balloon.inf", Some win2k3_64;
     "Balloon/2k3/amd64/balloon.pdb", Some win2k3_64;
     "Balloon/2k3/amd64/balloon.sys", Some win2k3_64;
-    "Balloon/2k3/amd64/blnsvr.exe", None;
+    "Balloon/2k3/amd64/blnsvr.exe", Some win2k3_64;
     "Balloon/2k3/amd64/blnsvr.pdb", Some win2k3_64;
-    "Balloon/2k3/x86/WdfCoInstaller01009.dll", None;
+    "Balloon/2k3/x86/WdfCoInstaller01009.dll", Some win2k3_32;
     "Balloon/2k3/x86/balloon.cat", Some win2k3_32;
     "Balloon/2k3/x86/balloon.inf", Some win2k3_32;
     "Balloon/2k3/x86/balloon.pdb", Some win2k3_32;
     "Balloon/2k3/x86/balloon.sys", Some win2k3_32;
-    "Balloon/2k3/x86/blnsvr.exe", None;
+    "Balloon/2k3/x86/blnsvr.exe", Some win2k3_32;
     "Balloon/2k3/x86/blnsvr.pdb", Some win2k3_32;
-    "Balloon/2k8/amd64/WdfCoInstaller01009.dll", None;
+    "Balloon/2k8/amd64/WdfCoInstaller01009.dll", Some win2k8_64;
     "Balloon/2k8/amd64/balloon.cat", Some win2k8_64;
     "Balloon/2k8/amd64/balloon.inf", Some win2k8_64;
     "Balloon/2k8/amd64/balloon.pdb", Some win2k8_64;
     "Balloon/2k8/amd64/balloon.sys", Some win2k8_64;
-    "Balloon/2k8/amd64/blnsvr.exe", None;
+    "Balloon/2k8/amd64/blnsvr.exe", Some win2k8_64;
     "Balloon/2k8/amd64/blnsvr.pdb", Some win2k8_64;
-    "Balloon/2k8/x86/WdfCoInstaller01009.dll", None;
+    "Balloon/2k8/x86/WdfCoInstaller01009.dll", Some win2k8_32;
     "Balloon/2k8/x86/balloon.cat", Some win2k8_32;
     "Balloon/2k8/x86/balloon.inf", Some win2k8_32;
     "Balloon/2k8/x86/balloon.pdb", Some win2k8_32;
     "Balloon/2k8/x86/balloon.sys", Some win2k8_32;
-    "Balloon/2k8/x86/blnsvr.exe", None;
+    "Balloon/2k8/x86/blnsvr.exe", Some win2k8_32;
     "Balloon/2k8/x86/blnsvr.pdb", Some win2k8_32;
-    "Balloon/2k8R2/amd64/WdfCoInstaller01009.dll", None;
+    "Balloon/2k8R2/amd64/WdfCoInstaller01009.dll", Some win2k8r2_64;
     "Balloon/2k8R2/amd64/balloon.cat", Some win2k8r2_64;
     "Balloon/2k8R2/amd64/balloon.inf", Some win2k8r2_64;
     "Balloon/2k8R2/amd64/balloon.pdb", Some win2k8r2_64;
     "Balloon/2k8R2/amd64/balloon.sys", Some win2k8r2_64;
-    "Balloon/2k8R2/amd64/blnsvr.exe", None;
+    "Balloon/2k8R2/amd64/blnsvr.exe", Some win2k8r2_64;
     "Balloon/2k8R2/amd64/blnsvr.pdb", Some win2k8r2_64;
-    "Balloon/w7/amd64/WdfCoInstaller01009.dll", None;
+    "Balloon/w7/amd64/WdfCoInstaller01009.dll", Some win7_64;
     "Balloon/w7/amd64/balloon.cat", Some win7_64;
     "Balloon/w7/amd64/balloon.inf", Some win7_64;
     "Balloon/w7/amd64/balloon.pdb", Some win7_64;
     "Balloon/w7/amd64/balloon.sys", Some win7_64;
-    "Balloon/w7/amd64/blnsvr.exe", None;
+    "Balloon/w7/amd64/blnsvr.exe", Some win7_64;
     "Balloon/w7/amd64/blnsvr.pdb", Some win7_64;
-    "Balloon/w7/x86/WdfCoInstaller01009.dll", None;
+    "Balloon/w7/x86/WdfCoInstaller01009.dll", Some win7_32;
     "Balloon/w7/x86/balloon.cat", Some win7_32;
     "Balloon/w7/x86/balloon.inf", Some win7_32;
     "Balloon/w7/x86/balloon.pdb", Some win7_32;
     "Balloon/w7/x86/balloon.sys", Some win7_32;
-    "Balloon/w7/x86/blnsvr.exe", None;
+    "Balloon/w7/x86/blnsvr.exe", Some win7_32;
     "Balloon/w7/x86/blnsvr.pdb", Some win7_32;
-    "Balloon/w8.1/amd64/WdfCoInstaller01011.dll", None;
+    "Balloon/w8.1/amd64/WdfCoInstaller01011.dll", Some win8_1_64;
     "Balloon/w8.1/amd64/balloon.cat", Some win8_1_64;
     "Balloon/w8.1/amd64/balloon.inf", Some win8_1_64;
     "Balloon/w8.1/amd64/balloon.pdb", Some win8_1_64;
     "Balloon/w8.1/amd64/balloon.sys", Some win8_1_64;
-    "Balloon/w8.1/amd64/blnsvr.exe", None;
+    "Balloon/w8.1/amd64/blnsvr.exe", Some win8_1_64;
     "Balloon/w8.1/amd64/blnsvr.pdb", Some win8_1_64;
-    "Balloon/w8.1/x86/WdfCoInstaller01011.dll", None;
+    "Balloon/w8.1/x86/WdfCoInstaller01011.dll", Some win8_1_32;
     "Balloon/w8.1/x86/balloon.cat", Some win8_1_32;
     "Balloon/w8.1/x86/balloon.inf", Some win8_1_32;
     "Balloon/w8.1/x86/balloon.pdb", Some win8_1_32;
     "Balloon/w8.1/x86/balloon.sys", Some win8_1_32;
-    "Balloon/w8.1/x86/blnsvr.exe", None;
+    "Balloon/w8.1/x86/blnsvr.exe", Some win8_1_32;
     "Balloon/w8.1/x86/blnsvr.pdb", Some win8_1_32;
-    "Balloon/w8/amd64/WdfCoInstaller01011.dll", None;
+    "Balloon/w8/amd64/WdfCoInstaller01011.dll", Some win8_64;
     "Balloon/w8/amd64/balloon.cat", Some win8_64;
     "Balloon/w8/amd64/balloon.inf", Some win8_64;
     "Balloon/w8/amd64/balloon.pdb", Some win8_64;
     "Balloon/w8/amd64/balloon.sys", Some win8_64;
-    "Balloon/w8/amd64/blnsvr.exe", None;
+    "Balloon/w8/amd64/blnsvr.exe", Some win8_64;
     "Balloon/w8/amd64/blnsvr.pdb", Some win8_64;
-    "Balloon/w8/x86/WdfCoInstaller01011.dll", None;
+    "Balloon/w8/x86/WdfCoInstaller01011.dll", Some win8_32;
     "Balloon/w8/x86/balloon.cat", Some win8_32;
     "Balloon/w8/x86/balloon.inf", Some win8_32;
     "Balloon/w8/x86/balloon.pdb", Some win8_32;
     "Balloon/w8/x86/balloon.sys", Some win8_32;
-    "Balloon/w8/x86/blnsvr.exe", None;
+    "Balloon/w8/x86/blnsvr.exe", Some win8_32;
     "Balloon/w8/x86/blnsvr.pdb", Some win8_32;
-    "Balloon/xp/x86/WdfCoInstaller01009.dll", None;
+    "Balloon/xp/x86/WdfCoInstaller01009.dll", Some winxp_32;
     "Balloon/xp/x86/balloon.cat", Some winxp_32;
     "Balloon/xp/x86/balloon.inf", Some winxp_32;
     "Balloon/xp/x86/balloon.pdb", Some winxp_32;
     "Balloon/xp/x86/balloon.sys", Some winxp_32;
-    "Balloon/xp/x86/blnsvr.exe", None;
+    "Balloon/xp/x86/blnsvr.exe", Some winxp_32;
     "Balloon/xp/x86/blnsvr.pdb", Some winxp_32;
     "NetKVM/2k12/amd64/netkvm.cat", Some win2k12_64;
     "NetKVM/2k12/amd64/netkvm.inf", Some win2k12_64;
     "NetKVM/2k12/amd64/netkvm.pdb", Some win2k12_64;
     "NetKVM/2k12/amd64/netkvm.sys", Some win2k12_64;
-    "NetKVM/2k12/amd64/netkvmco.dll", None;
-    "NetKVM/2k12/amd64/readme.doc", None;
+    "NetKVM/2k12/amd64/netkvmco.dll", Some win2k12_64;
+    "NetKVM/2k12/amd64/readme.doc", Some win2k12_64;
     "NetKVM/2k12R2/amd64/netkvm.cat", Some win2k12r2_64;
     "NetKVM/2k12R2/amd64/netkvm.inf", Some win2k12r2_64;
     "NetKVM/2k12R2/amd64/netkvm.pdb", Some win2k12r2_64;
     "NetKVM/2k12R2/amd64/netkvm.sys", Some win2k12r2_64;
-    "NetKVM/2k12R2/amd64/netkvmco.dll", None;
-    "NetKVM/2k12R2/amd64/readme.doc", None;
+    "NetKVM/2k12R2/amd64/netkvmco.dll", Some win2k12r2_64;
+    "NetKVM/2k12R2/amd64/readme.doc", Some win2k12r2_64;
     "NetKVM/2k3/amd64/netkvm.cat", Some win2k3_64;
     "NetKVM/2k3/amd64/netkvm.inf", Some win2k3_64;
     "NetKVM/2k3/amd64/netkvm.pdb", Some win2k3_64;
@@ -286,56 +286,56 @@ let test_virtio_iso_path_matches_guest_os ctx =
     "NetKVM/2k8/amd64/netkvm.inf", Some win2k8_64;
     "NetKVM/2k8/amd64/netkvm.pdb", Some win2k8_64;
     "NetKVM/2k8/amd64/netkvm.sys", Some win2k8_64;
-    "NetKVM/2k8/amd64/netkvmco.dll", None;
-    "NetKVM/2k8/amd64/readme.doc", None;
+    "NetKVM/2k8/amd64/netkvmco.dll", Some win2k8_64;
+    "NetKVM/2k8/amd64/readme.doc", Some win2k8_64;
     "NetKVM/2k8/x86/netkvm.cat", Some win2k8_32;
     "NetKVM/2k8/x86/netkvm.inf", Some win2k8_32;
     "NetKVM/2k8/x86/netkvm.pdb", Some win2k8_32;
     "NetKVM/2k8/x86/netkvm.sys", Some win2k8_32;
-    "NetKVM/2k8/x86/netkvmco.dll", None;
-    "NetKVM/2k8/x86/readme.doc", None;
+    "NetKVM/2k8/x86/netkvmco.dll", Some win2k8_32;
+    "NetKVM/2k8/x86/readme.doc", Some win2k8_32;
     "NetKVM/2k8R2/amd64/netkvm.cat", Some win2k8r2_64;
     "NetKVM/2k8R2/amd64/netkvm.inf", Some win2k8r2_64;
     "NetKVM/2k8R2/amd64/netkvm.pdb", Some win2k8r2_64;
     "NetKVM/2k8R2/amd64/netkvm.sys", Some win2k8r2_64;
-    "NetKVM/2k8R2/amd64/netkvmco.dll", None;
-    "NetKVM/2k8R2/amd64/readme.doc", None;
+    "NetKVM/2k8R2/amd64/netkvmco.dll", Some win2k8r2_64;
+    "NetKVM/2k8R2/amd64/readme.doc", Some win2k8r2_64;
     "NetKVM/w7/amd64/netkvm.cat", Some win7_64;
     "NetKVM/w7/amd64/netkvm.inf", Some win7_64;
     "NetKVM/w7/amd64/netkvm.pdb", Some win7_64;
     "NetKVM/w7/amd64/netkvm.sys", Some win7_64;
-    "NetKVM/w7/amd64/netkvmco.dll", None;
-    "NetKVM/w7/amd64/readme.doc", None;
+    "NetKVM/w7/amd64/netkvmco.dll", Some win7_64;
+    "NetKVM/w7/amd64/readme.doc", Some win7_64;
     "NetKVM/w7/x86/netkvm.cat", Some win7_32;
     "NetKVM/w7/x86/netkvm.inf", Some win7_32;
     "NetKVM/w7/x86/netkvm.pdb", Some win7_32;
     "NetKVM/w7/x86/netkvm.sys", Some win7_32;
-    "NetKVM/w7/x86/netkvmco.dll", None;
-    "NetKVM/w7/x86/readme.doc", None;
+    "NetKVM/w7/x86/netkvmco.dll", Some win7_32;
+    "NetKVM/w7/x86/readme.doc", Some win7_32;
     "NetKVM/w8.1/amd64/netkvm.cat", Some win8_1_64;
     "NetKVM/w8.1/amd64/netkvm.inf", Some win8_1_64;
     "NetKVM/w8.1/amd64/netkvm.pdb", Some win8_1_64;
     "NetKVM/w8.1/amd64/netkvm.sys", Some win8_1_64;
-    "NetKVM/w8.1/amd64/netkvmco.dll", None;
-    "NetKVM/w8.1/amd64/readme.doc", None;
+    "NetKVM/w8.1/amd64/netkvmco.dll", Some win8_1_64;
+    "NetKVM/w8.1/amd64/readme.doc", Some win8_1_64;
     "NetKVM/w8.1/x86/netkvm.cat", Some win8_1_32;
     "NetKVM/w8.1/x86/netkvm.inf", Some win8_1_32;
     "NetKVM/w8.1/x86/netkvm.pdb", Some win8_1_32;
     "NetKVM/w8.1/x86/netkvm.sys", Some win8_1_32;
-    "NetKVM/w8.1/x86/netkvmco.dll", None;
-    "NetKVM/w8.1/x86/readme.doc", None;
+    "NetKVM/w8.1/x86/netkvmco.dll", Some win8_1_32;
+    "NetKVM/w8.1/x86/readme.doc", Some win8_1_32;
     "NetKVM/w8/amd64/netkvm.cat", Some win8_64;
     "NetKVM/w8/amd64/netkvm.inf", Some win8_64;
     "NetKVM/w8/amd64/netkvm.pdb", Some win8_64;
     "NetKVM/w8/amd64/netkvm.sys", Some win8_64;
-    "NetKVM/w8/amd64/netkvmco.dll", None;
-    "NetKVM/w8/amd64/readme.doc", None;
+    "NetKVM/w8/amd64/netkvmco.dll", Some win8_64;
+    "NetKVM/w8/amd64/readme.doc", Some win8_64;
     "NetKVM/w8/x86/netkvm.cat", Some win8_32;
     "NetKVM/w8/x86/netkvm.inf", Some win8_32;
     "NetKVM/w8/x86/netkvm.pdb", Some win8_32;
     "NetKVM/w8/x86/netkvm.sys", Some win8_32;
-    "NetKVM/w8/x86/netkvmco.dll", None;
-    "NetKVM/w8/x86/readme.doc", None;
+    "NetKVM/w8/x86/netkvmco.dll", Some win8_32;
+    "NetKVM/w8/x86/readme.doc", Some win8_32;
     "NetKVM/xp/x86/netkvm.cat", Some winxp_32;
     "NetKVM/xp/x86/netkvm.inf", Some winxp_32;
     "NetKVM/xp/x86/netkvm.pdb", Some winxp_32;
@@ -343,83 +343,83 @@ let test_virtio_iso_path_matches_guest_os ctx =
     "guest-agent/qemu-ga-x64.msi", None;
     "guest-agent/qemu-ga-x86.msi", None;
     "qemupciserial/qemupciserial.inf", None;
-    "viorng/2k12/amd64/WdfCoInstaller01011.dll", None;
+    "viorng/2k12/amd64/WdfCoInstaller01011.dll", Some win2k12_64;
     "viorng/2k12/amd64/viorng.cat", Some win2k12_64;
     "viorng/2k12/amd64/viorng.inf", Some win2k12_64;
     "viorng/2k12/amd64/viorng.pdb", Some win2k12_64;
     "viorng/2k12/amd64/viorng.sys", Some win2k12_64;
-    "viorng/2k12/amd64/viorngci.dll", None;
-    "viorng/2k12/amd64/viorngum.dll", None;
-    "viorng/2k12R2/amd64/WdfCoInstaller01011.dll", None;
+    "viorng/2k12/amd64/viorngci.dll", Some win2k12_64;
+    "viorng/2k12/amd64/viorngum.dll", Some win2k12_64;
+    "viorng/2k12R2/amd64/WdfCoInstaller01011.dll", Some win2k12r2_64;
     "viorng/2k12R2/amd64/viorng.cat", Some win2k12r2_64;
     "viorng/2k12R2/amd64/viorng.inf", Some win2k12r2_64;
     "viorng/2k12R2/amd64/viorng.pdb", Some win2k12r2_64;
     "viorng/2k12R2/amd64/viorng.sys", Some win2k12r2_64;
-    "viorng/2k12R2/amd64/viorngci.dll", None;
-    "viorng/2k12R2/amd64/viorngum.dll", None;
-    "viorng/2k8/amd64/WdfCoInstaller01009.dll", None;
+    "viorng/2k12R2/amd64/viorngci.dll", Some win2k12r2_64;
+    "viorng/2k12R2/amd64/viorngum.dll", Some win2k12r2_64;
+    "viorng/2k8/amd64/WdfCoInstaller01009.dll", Some win2k8_64;
     "viorng/2k8/amd64/viorng.cat", Some win2k8_64;
     "viorng/2k8/amd64/viorng.inf", Some win2k8_64;
     "viorng/2k8/amd64/viorng.pdb", Some win2k8_64;
     "viorng/2k8/amd64/viorng.sys", Some win2k8_64;
-    "viorng/2k8/amd64/viorngci.dll", None;
-    "viorng/2k8/amd64/viorngum.dll", None;
-    "viorng/2k8/x86/WdfCoInstaller01009.dll", None;
+    "viorng/2k8/amd64/viorngci.dll", Some win2k8_64;
+    "viorng/2k8/amd64/viorngum.dll", Some win2k8_64;
+    "viorng/2k8/x86/WdfCoInstaller01009.dll", Some win2k8_32;
     "viorng/2k8/x86/viorng.cat", Some win2k8_32;
     "viorng/2k8/x86/viorng.inf", Some win2k8_32;
     "viorng/2k8/x86/viorng.pdb", Some win2k8_32;
     "viorng/2k8/x86/viorng.sys", Some win2k8_32;
-    "viorng/2k8/x86/viorngci.dll", None;
-    "viorng/2k8/x86/viorngum.dll", None;
-    "viorng/2k8R2/amd64/WdfCoInstaller01009.dll", None;
+    "viorng/2k8/x86/viorngci.dll", Some win2k8_32;
+    "viorng/2k8/x86/viorngum.dll", Some win2k8_32;
+    "viorng/2k8R2/amd64/WdfCoInstaller01009.dll", Some win2k8r2_64;
     "viorng/2k8R2/amd64/viorng.cat", Some win2k8r2_64;
     "viorng/2k8R2/amd64/viorng.inf", Some win2k8r2_64;
     "viorng/2k8R2/amd64/viorng.pdb", Some win2k8r2_64;
     "viorng/2k8R2/amd64/viorng.sys", Some win2k8r2_64;
-    "viorng/2k8R2/amd64/viorngci.dll", None;
-    "viorng/2k8R2/amd64/viorngum.dll", None;
-    "viorng/w7/amd64/WdfCoInstaller01009.dll", None;
+    "viorng/2k8R2/amd64/viorngci.dll", Some win2k8r2_64;
+    "viorng/2k8R2/amd64/viorngum.dll", Some win2k8r2_64;
+    "viorng/w7/amd64/WdfCoInstaller01009.dll", Some win7_64;
     "viorng/w7/amd64/viorng.cat", Some win7_64;
     "viorng/w7/amd64/viorng.inf", Some win7_64;
     "viorng/w7/amd64/viorng.pdb", Some win7_64;
     "viorng/w7/amd64/viorng.sys", Some win7_64;
-    "viorng/w7/amd64/viorngci.dll", None;
-    "viorng/w7/amd64/viorngum.dll", None;
-    "viorng/w7/x86/WdfCoInstaller01009.dll", None;
+    "viorng/w7/amd64/viorngci.dll", Some win7_64;
+    "viorng/w7/amd64/viorngum.dll", Some win7_64;
+    "viorng/w7/x86/WdfCoInstaller01009.dll", Some win7_32;
     "viorng/w7/x86/viorng.cat", Some win7_32;
     "viorng/w7/x86/viorng.inf", Some win7_32;
     "viorng/w7/x86/viorng.pdb", Some win7_32;
     "viorng/w7/x86/viorng.sys", Some win7_32;
-    "viorng/w7/x86/viorngci.dll", None;
-    "viorng/w7/x86/viorngum.dll", None;
-    "viorng/w8.1/amd64/WdfCoInstaller01011.dll", None;
+    "viorng/w7/x86/viorngci.dll", Some win7_32;
+    "viorng/w7/x86/viorngum.dll", Some win7_32;
+    "viorng/w8.1/amd64/WdfCoInstaller01011.dll", Some win8_1_64;
     "viorng/w8.1/amd64/viorng.cat", Some win8_1_64;
     "viorng/w8.1/amd64/viorng.inf", Some win8_1_64;
     "viorng/w8.1/amd64/viorng.pdb", Some win8_1_64;
     "viorng/w8.1/amd64/viorng.sys", Some win8_1_64;
-    "viorng/w8.1/amd64/viorngci.dll", None;
-    "viorng/w8.1/amd64/viorngum.dll", None;
-    "viorng/w8.1/x86/WdfCoInstaller01011.dll", None;
+    "viorng/w8.1/amd64/viorngci.dll", Some win8_1_64;
+    "viorng/w8.1/amd64/viorngum.dll", Some win8_1_64;
+    "viorng/w8.1/x86/WdfCoInstaller01011.dll", Some win8_1_32;
     "viorng/w8.1/x86/viorng.cat", Some win8_1_32;
     "viorng/w8.1/x86/viorng.inf", Some win8_1_32;
     "viorng/w8.1/x86/viorng.pdb", Some win8_1_32;
     "viorng/w8.1/x86/viorng.sys", Some win8_1_32;
-    "viorng/w8.1/x86/viorngci.dll", None;
-    "viorng/w8.1/x86/viorngum.dll", None;
-    "viorng/w8/amd64/WdfCoInstaller01011.dll", None;
+    "viorng/w8.1/x86/viorngci.dll", Some win8_1_32;
+    "viorng/w8.1/x86/viorngum.dll", Some win8_1_32;
+    "viorng/w8/amd64/WdfCoInstaller01011.dll", Some win8_64;
     "viorng/w8/amd64/viorng.cat", Some win8_64;
     "viorng/w8/amd64/viorng.inf", Some win8_64;
     "viorng/w8/amd64/viorng.pdb", Some win8_64;
     "viorng/w8/amd64/viorng.sys", Some win8_64;
-    "viorng/w8/amd64/viorngci.dll", None;
-    "viorng/w8/amd64/viorngum.dll", None;
-    "viorng/w8/x86/WdfCoInstaller01011.dll", None;
+    "viorng/w8/amd64/viorngci.dll", Some win8_64;
+    "viorng/w8/amd64/viorngum.dll", Some win8_64;
+    "viorng/w8/x86/WdfCoInstaller01011.dll", Some win8_32;
     "viorng/w8/x86/viorng.cat", Some win8_32;
     "viorng/w8/x86/viorng.inf", Some win8_32;
     "viorng/w8/x86/viorng.pdb", Some win8_32;
     "viorng/w8/x86/viorng.sys", Some win8_32;
-    "viorng/w8/x86/viorngci.dll", None;
-    "viorng/w8/x86/viorngum.dll", None;
+    "viorng/w8/x86/viorngci.dll", Some win8_32;
+    "viorng/w8/x86/viorngum.dll", Some win8_32;
     "vioscsi/2k12/amd64/vioscsi.cat", Some win2k12_64;
     "vioscsi/2k12/amd64/vioscsi.inf", Some win2k12_64;
     "vioscsi/2k12/amd64/vioscsi.pdb", Some win2k12_64;
@@ -464,72 +464,72 @@ let test_virtio_iso_path_matches_guest_os ctx =
     "vioscsi/w8/x86/vioscsi.inf", Some win8_32;
     "vioscsi/w8/x86/vioscsi.pdb", Some win8_32;
     "vioscsi/w8/x86/vioscsi.sys", Some win8_32;
-    "vioserial/2k12/amd64/WdfCoInstaller01011.dll", None;
+    "vioserial/2k12/amd64/WdfCoInstaller01011.dll", Some win2k12_64;
     "vioserial/2k12/amd64/vioser.cat", Some win2k12_64;
     "vioserial/2k12/amd64/vioser.inf", Some win2k12_64;
     "vioserial/2k12/amd64/vioser.pdb", Some win2k12_64;
     "vioserial/2k12/amd64/vioser.sys", Some win2k12_64;
-    "vioserial/2k12R2/amd64/WdfCoInstaller01011.dll", None;
+    "vioserial/2k12R2/amd64/WdfCoInstaller01011.dll", Some win2k12r2_64;
     "vioserial/2k12R2/amd64/vioser.cat", Some win2k12r2_64;
     "vioserial/2k12R2/amd64/vioser.inf", Some win2k12r2_64;
     "vioserial/2k12R2/amd64/vioser.pdb", Some win2k12r2_64;
     "vioserial/2k12R2/amd64/vioser.sys", Some win2k12r2_64;
-    "vioserial/2k3/amd64/WdfCoInstaller01009.dll", None;
+    "vioserial/2k3/amd64/WdfCoInstaller01009.dll", Some win2k3_64;
     "vioserial/2k3/amd64/vioser.cat", Some win2k3_64;
     "vioserial/2k3/amd64/vioser.inf", Some win2k3_64;
     "vioserial/2k3/amd64/vioser.pdb", Some win2k3_64;
     "vioserial/2k3/amd64/vioser.sys", Some win2k3_64;
-    "vioserial/2k3/x86/WdfCoInstaller01009.dll", None;
+    "vioserial/2k3/x86/WdfCoInstaller01009.dll", Some win2k3_32;
     "vioserial/2k3/x86/vioser.cat", Some win2k3_32;
     "vioserial/2k3/x86/vioser.inf", Some win2k3_32;
     "vioserial/2k3/x86/vioser.pdb", Some win2k3_32;
     "vioserial/2k3/x86/vioser.sys", Some win2k3_32;
-    "vioserial/2k8/amd64/WdfCoInstaller01009.dll", None;
+    "vioserial/2k8/amd64/WdfCoInstaller01009.dll", Some win2k8_64;
     "vioserial/2k8/amd64/vioser.cat", Some win2k8_64;
     "vioserial/2k8/amd64/vioser.inf", Some win2k8_64;
     "vioserial/2k8/amd64/vioser.pdb", Some win2k8_64;
     "vioserial/2k8/amd64/vioser.sys", Some win2k8_64;
-    "vioserial/2k8/x86/WdfCoInstaller01009.dll", None;
+    "vioserial/2k8/x86/WdfCoInstaller01009.dll", Some win2k8_32;
     "vioserial/2k8/x86/vioser.cat", Some win2k8_32;
     "vioserial/2k8/x86/vioser.inf", Some win2k8_32;
     "vioserial/2k8/x86/vioser.pdb", Some win2k8_32;
     "vioserial/2k8/x86/vioser.sys", Some win2k8_32;
-    "vioserial/2k8R2/amd64/WdfCoInstaller01009.dll", None;
+    "vioserial/2k8R2/amd64/WdfCoInstaller01009.dll", Some win2k8r2_64;
     "vioserial/2k8R2/amd64/vioser.cat", Some win2k8r2_64;
     "vioserial/2k8R2/amd64/vioser.inf", Some win2k8r2_64;
     "vioserial/2k8R2/amd64/vioser.pdb", Some win2k8r2_64;
     "vioserial/2k8R2/amd64/vioser.sys", Some win2k8r2_64;
-    "vioserial/w7/amd64/WdfCoInstaller01009.dll", None;
+    "vioserial/w7/amd64/WdfCoInstaller01009.dll", Some win7_64;
     "vioserial/w7/amd64/vioser.cat", Some win7_64;
     "vioserial/w7/amd64/vioser.inf", Some win7_64;
     "vioserial/w7/amd64/vioser.pdb", Some win7_64;
     "vioserial/w7/amd64/vioser.sys", Some win7_64;
-    "vioserial/w7/x86/WdfCoInstaller01009.dll", None;
+    "vioserial/w7/x86/WdfCoInstaller01009.dll", Some win7_32;
     "vioserial/w7/x86/vioser.cat", Some win7_32;
     "vioserial/w7/x86/vioser.inf", Some win7_32;
     "vioserial/w7/x86/vioser.pdb", Some win7_32;
     "vioserial/w7/x86/vioser.sys", Some win7_32;
-    "vioserial/w8.1/amd64/WdfCoInstaller01011.dll", None;
+    "vioserial/w8.1/amd64/WdfCoInstaller01011.dll", Some win8_1_64;
     "vioserial/w8.1/amd64/vioser.cat", Some win8_1_64;
     "vioserial/w8.1/amd64/vioser.inf", Some win8_1_64;
     "vioserial/w8.1/amd64/vioser.pdb", Some win8_1_64;
     "vioserial/w8.1/amd64/vioser.sys", Some win8_1_64;
-    "vioserial/w8.1/x86/WdfCoInstaller01011.dll", None;
+    "vioserial/w8.1/x86/WdfCoInstaller01011.dll", Some win8_1_32;
     "vioserial/w8.1/x86/vioser.cat", Some win8_1_32;
     "vioserial/w8.1/x86/vioser.inf", Some win8_1_32;
     "vioserial/w8.1/x86/vioser.pdb", Some win8_1_32;
     "vioserial/w8.1/x86/vioser.sys", Some win8_1_32;
-    "vioserial/w8/amd64/WdfCoInstaller01011.dll", None;
+    "vioserial/w8/amd64/WdfCoInstaller01011.dll", Some win8_64;
     "vioserial/w8/amd64/vioser.cat", Some win8_64;
     "vioserial/w8/amd64/vioser.inf", Some win8_64;
     "vioserial/w8/amd64/vioser.pdb", Some win8_64;
     "vioserial/w8/amd64/vioser.sys", Some win8_64;
-    "vioserial/w8/x86/WdfCoInstaller01011.dll", None;
+    "vioserial/w8/x86/WdfCoInstaller01011.dll", Some win8_32;
     "vioserial/w8/x86/vioser.cat", Some win8_32;
     "vioserial/w8/x86/vioser.inf", Some win8_32;
     "vioserial/w8/x86/vioser.pdb", Some win8_32;
     "vioserial/w8/x86/vioser.sys", Some win8_32;
-    "vioserial/xp/x86/WdfCoInstaller01009.dll", None;
+    "vioserial/xp/x86/WdfCoInstaller01009.dll", Some winxp_32;
     "vioserial/xp/x86/vioser.cat", Some winxp_32;
     "vioserial/xp/x86/vioser.inf", Some winxp_32;
     "vioserial/xp/x86/vioser.pdb", Some winxp_32;
@@ -619,7 +619,7 @@ let test_virtio_iso_path_matches_guest_os ctx =
     "drivers/i386/Win2008/vioscsi.inf", Some win2k8_32;
     "drivers/i386/Win7/viostor.inf", Some win7_32;
     "drivers/i386/Win7/viostor.sys", Some win7_32;
-    "drivers/i386/Win7/qxldd.dll", None;
+    "drivers/i386/Win7/qxldd.dll", Some win7_32;
     "drivers/i386/Win7/qxl.sys", Some win7_32;
     "drivers/i386/Win7/vioscsi.cat", Some win7_32;
     "drivers/i386/Win7/netkvm.inf", Some win7_32;
@@ -647,7 +647,7 @@ let test_virtio_iso_path_matches_guest_os ctx =
     "drivers/i386/Win8/vioscsi.inf", Some win8_32;
     "drivers/i386/WinXP/viostor.inf", Some winxp_32;
     "drivers/i386/WinXP/viostor.sys", Some winxp_32;
-    "drivers/i386/WinXP/qxldd.dll", None;
+    "drivers/i386/WinXP/qxldd.dll", Some winxp_32;
     "drivers/i386/WinXP/qxl.sys", Some winxp_32;
     "drivers/i386/WinXP/netkvm.inf", Some winxp_32;
     "drivers/i386/WinXP/netkvm.sys", Some winxp_32;
@@ -675,7 +675,7 @@ let test_virtio_iso_path_matches_guest_os ctx =
     "drivers/amd64/Win2008/vioscsi.inf", Some win2k8_64;
     "drivers/amd64/Win7/viostor.inf", Some win7_64;
     "drivers/amd64/Win7/viostor.sys", Some win7_64;
-    "drivers/amd64/Win7/qxldd.dll", None;
+    "drivers/amd64/Win7/qxldd.dll", Some win7_64;
     "drivers/amd64/Win7/qxl.sys", Some win7_64;
     "drivers/amd64/Win7/vioscsi.cat", Some win7_64;
     "drivers/amd64/Win7/netkvm.inf", Some win7_64;
@@ -712,7 +712,7 @@ let test_virtio_iso_path_matches_guest_os ctx =
     "drivers/amd64/Win2012/vioscsi.inf", Some win2k12_64;
     "drivers/amd64/Win2008R2/viostor.inf", Some win2k8r2_64;
     "drivers/amd64/Win2008R2/viostor.sys", Some win2k8r2_64;
-    "drivers/amd64/Win2008R2/qxldd.dll", None;
+    "drivers/amd64/Win2008R2/qxldd.dll", Some win2k8r2_64;
     "drivers/amd64/Win2008R2/qxl.sys", Some win2k8r2_64;
     "drivers/amd64/Win2008R2/vioscsi.cat", Some win2k8r2_64;
     "drivers/amd64/Win2008R2/netkvm.inf", Some win2k8r2_64;
@@ -767,16 +767,16 @@ let test_virtio_iso_path_matches_guest_os ctx =
 
 let test_shell_unquote ctx =
   let printer = identity in
-  assert_equal ~printer "a" (Linux.shell_unquote "a");
-  assert_equal ~printer "b" (Linux.shell_unquote "'b'");
-  assert_equal ~printer "c" (Linux.shell_unquote "\"c\"");
-  assert_equal ~printer "dd" (Linux.shell_unquote "\"dd\"");
-  assert_equal ~printer "e\\e" (Linux.shell_unquote "\"e\\\\e\"");
-  assert_equal ~printer "f\\" (Linux.shell_unquote "\"f\\\\\"");
-  assert_equal ~printer "\\g" (Linux.shell_unquote "\"\\\\g\"");
-  assert_equal ~printer "h\\-h" (Linux.shell_unquote "\"h\\-h\"");
-  assert_equal ~printer "i`" (Linux.shell_unquote "\"i\\`\"");
-  assert_equal ~printer "j\"" (Linux.shell_unquote "\"j\\\"\"")
+  assert_equal ~printer "a" (Utils.shell_unquote "a");
+  assert_equal ~printer "b" (Utils.shell_unquote "'b'");
+  assert_equal ~printer "c" (Utils.shell_unquote "\"c\"");
+  assert_equal ~printer "dd" (Utils.shell_unquote "\"dd\"");
+  assert_equal ~printer "e\\e" (Utils.shell_unquote "\"e\\\\e\"");
+  assert_equal ~printer "f\\" (Utils.shell_unquote "\"f\\\\\"");
+  assert_equal ~printer "\\g" (Utils.shell_unquote "\"\\\\g\"");
+  assert_equal ~printer "h\\-h" (Utils.shell_unquote "\"h\\-h\"");
+  assert_equal ~printer "i`" (Utils.shell_unquote "\"i\\`\"");
+  assert_equal ~printer "j\"" (Utils.shell_unquote "\"j\\\"\"")
 
 (* Suites declaration. *)
 let suite =
@@ -787,7 +787,7 @@ let suite =
       "Utils.drive_index" >:: test_drive_index;
       "Windows_virtio.virtio_iso_path_matches_guest_os" >::
         test_virtio_iso_path_matches_guest_os;
-      "Linux.shell_unquote" >:: test_shell_unquote;
+      "Utils.shell_unquote" >:: test_shell_unquote;
     ]
 
 let () =
