@@ -45,35 +45,34 @@ let get_session_cookie password scheme uri sslverify url =
   if !session_cookie <> "" then
     Some !session_cookie
   else (
-    let curl_args = [
+    let curl_args = ref [
       "head", None;
       "silent", None;
       "url", Some url;
     ] in
-    let curl_args =
-      match uri.uri_user, password with
-      | None, None -> curl_args
-      | None, Some _ ->
-         warning (f_"--password-file parameter ignored because 'user@' was not given in the URL");
-         curl_args
-      | Some user, None ->
-         ("user", Some user) :: curl_args
-      | Some user, Some password ->
-         ("user", Some (user ^ ":" ^ password)) :: curl_args in
-    let curl_args =
-      if not sslverify then ("insecure", None) :: curl_args else curl_args in
+    (match uri.uri_user, password with
+     | None, None -> ()
+     | None, Some _ ->
+        warning (f_"--password-file parameter ignored because 'user@' was not given in the URL")
+     | Some user, None ->
+        push_back curl_args ("user", Some user)
+     | Some user, Some password ->
+        push_back curl_args ("user", Some (user ^ ":" ^ password))
+    );
+    if not sslverify then push_back curl_args ("insecure", None);
 
-    let lines = Curl.run curl_args in
+    let curl_h = Curl.create !curl_args in
+    let lines = Curl.run curl_h in
 
     let dump_response chan =
-      Curl.print_curl_command chan curl_args;
+      Curl.print chan curl_h;
 
       (* Dump out the output of the command. *)
       List.iter (fun x -> fprintf chan "%s\n" x) lines;
       flush chan
     in
 
-    if verbose () then dump_response stdout;
+    if verbose () then dump_response stderr;
 
     (* Look for the last HTTP/x.y NNN status code in the output. *)
     let status = ref "" in
@@ -240,8 +239,7 @@ let map_source_to_uri readahead dcPath password uri scheme server path =
     | None -> json_params
     | Some cookie -> ("file.cookie", JSON.String cookie) :: json_params in
 
-  if verbose () then
-    printf "vcenter: json parameters: %s\n" (JSON.string_of_doc json_params);
+  debug "vcenter: json parameters: %s" (JSON.string_of_doc json_params);
 
   (* Turn the JSON parameters into a 'json:' protocol string.
    * Note this requires qemu-img >= 2.1.0.
